
using namespace System.Management.Automation
using namespace System.Management.Automation.Language

Register-ArgumentCompleter -Native -CommandName 'sq' -ScriptBlock {
    param($wordToComplete, $commandAst, $cursorPosition)

    $commandElements = $commandAst.CommandElements
    $command = @(
        'sq'
        for ($i = 1; $i -lt $commandElements.Count; $i++) {
            $element = $commandElements[$i]
            if ($element -isnot [StringConstantExpressionAst] -or
                $element.StringConstantType -ne [StringConstantType]::BareWord -or
                $element.Value.StartsWith('-') -or
                $element.Value -eq $wordToComplete) {
                break
        }
        $element.Value
    }) -join ';'

    $completions = @(switch ($command) {
        'sq' {
            [CompletionResult]::new('--cli-version', '--cli-version', [CompletionResultType]::ParameterName, 'Select a CLI version')
            [CompletionResult]::new('--home', '--home', [CompletionResultType]::ParameterName, 'Set the home directory')
            [CompletionResult]::new('--key-store', '--key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', '--cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--keyring', '--keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--known-notation', '--known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', '--time', [CompletionResultType]::ParameterName, 'Set the reference time as an ISO 8601 formatted timestamp')
            [CompletionResult]::new('--policy-as-of', '--policy-as-of', [CompletionResultType]::ParameterName, 'Select the cryptographic policy as of the specified time')
            [CompletionResult]::new('--trust-root', '--trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('--password-file', '--password-file', [CompletionResultType]::ParameterName, 'Seed the password cache with the specified password')
            [CompletionResult]::new('--overwrite', '--overwrite', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('-v', '-v', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('--verbose', '--verbose', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--batch', '--batch', [CompletionResultType]::ParameterName, 'Prevents any kind of prompting')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('encrypt', 'encrypt', [CompletionResultType]::ParameterValue, 'Encrypt a message')
            [CompletionResult]::new('decrypt', 'decrypt', [CompletionResultType]::ParameterValue, 'Decrypt a message')
            [CompletionResult]::new('sign', 'sign', [CompletionResultType]::ParameterValue, 'Sign messages or data files')
            [CompletionResult]::new('verify', 'verify', [CompletionResultType]::ParameterValue, 'Verify signed messages or detached signatures')
            [CompletionResult]::new('download', 'download', [CompletionResultType]::ParameterValue, 'Download and authenticate the data')
            [CompletionResult]::new('inspect', 'inspect', [CompletionResultType]::ParameterValue, 'Inspect data, like file(1)')
            [CompletionResult]::new('cert', 'cert', [CompletionResultType]::ParameterValue, 'Manage certificates')
            [CompletionResult]::new('key', 'key', [CompletionResultType]::ParameterValue, 'Manage keys')
            [CompletionResult]::new('pki', 'pki', [CompletionResultType]::ParameterValue, 'Authenticate certs using the Web of Trust')
            [CompletionResult]::new('network', 'network', [CompletionResultType]::ParameterValue, 'Retrieve and publish certificates over the network')
            [CompletionResult]::new('keyring', 'keyring', [CompletionResultType]::ParameterValue, 'Manage collections of keys or certs')
            [CompletionResult]::new('packet', 'packet', [CompletionResultType]::ParameterValue, 'Low-level packet manipulation')
            [CompletionResult]::new('config', 'config', [CompletionResultType]::ParameterValue, 'Query, inspect, and create the configuration file')
            [CompletionResult]::new('version', 'version', [CompletionResultType]::ParameterValue, 'Detailed version and output version information')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'sq;encrypt' {
            [CompletionResult]::new('--output', '--output', [CompletionResultType]::ParameterName, 'Write to FILE or stdout if omitted')
            [CompletionResult]::new('--for', '--for', [CompletionResultType]::ParameterName, 'Use certificates with the specified fingerprint or key ID')
            [CompletionResult]::new('--for-userid', '--for-userid', [CompletionResultType]::ParameterName, 'Use certificates with the specified user ID')
            [CompletionResult]::new('--for-email', '--for-email', [CompletionResultType]::ParameterName, 'Use certificates where a user ID includes the specified email address')
            [CompletionResult]::new('--for-file', '--for-file', [CompletionResultType]::ParameterName, 'Read certificates from PATH')
            [CompletionResult]::new('--with-password-file', '--with-password-file', [CompletionResultType]::ParameterName, 'File containing password to encrypt the message')
            [CompletionResult]::new('--set-metadata-filename', '--set-metadata-filename', [CompletionResultType]::ParameterName, 'Set the filename of the encrypted file as metadata')
            [CompletionResult]::new('--signer', '--signer', [CompletionResultType]::ParameterName, 'Sign the message using the key with the specified fingerprint or key ID')
            [CompletionResult]::new('--signer-userid', '--signer-userid', [CompletionResultType]::ParameterName, 'Sign the message using the key with the specified user ID')
            [CompletionResult]::new('--signer-email', '--signer-email', [CompletionResultType]::ParameterName, 'Sign the message using the key where a user ID includes the specified email address')
            [CompletionResult]::new('--signer-file', '--signer-file', [CompletionResultType]::ParameterName, 'Sign the message using the key read from PATH')
            [CompletionResult]::new('--signature-notation', '--signature-notation', [CompletionResultType]::ParameterName, 'Add a notation to the signature')
            [CompletionResult]::new('--encrypt-for', '--encrypt-for', [CompletionResultType]::ParameterName, 'Select what kind of keys are considered for encryption')
            [CompletionResult]::new('--compression', '--compression', [CompletionResultType]::ParameterName, 'Select compression scheme to use')
            [CompletionResult]::new('--profile', '--profile', [CompletionResultType]::ParameterName, 'Select the default OpenPGP standard for the encryption container')
            [CompletionResult]::new('--cli-version', '--cli-version', [CompletionResultType]::ParameterName, 'Select a CLI version')
            [CompletionResult]::new('--home', '--home', [CompletionResultType]::ParameterName, 'Set the home directory')
            [CompletionResult]::new('--key-store', '--key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', '--cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--keyring', '--keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--known-notation', '--known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', '--time', [CompletionResultType]::ParameterName, 'Set the reference time as an ISO 8601 formatted timestamp')
            [CompletionResult]::new('--policy-as-of', '--policy-as-of', [CompletionResultType]::ParameterName, 'Select the cryptographic policy as of the specified time')
            [CompletionResult]::new('--trust-root', '--trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('--password-file', '--password-file', [CompletionResultType]::ParameterName, 'Seed the password cache with the specified password')
            [CompletionResult]::new('--binary', '--binary', [CompletionResultType]::ParameterName, 'Emit binary data')
            [CompletionResult]::new('--for-self', '--for-self', [CompletionResultType]::ParameterName, 'Encrypt the message for yourself')
            [CompletionResult]::new('--with-password', '--with-password', [CompletionResultType]::ParameterName, 'Prompt to add a password to encrypt with')
            [CompletionResult]::new('--signer-self', '--signer-self', [CompletionResultType]::ParameterName, 'Sign using your default signer keys')
            [CompletionResult]::new('--without-signature', '--without-signature', [CompletionResultType]::ParameterName, 'Do not sign the message')
            [CompletionResult]::new('--use-expired-subkey', '--use-expired-subkey', [CompletionResultType]::ParameterName, 'Fall back to expired encryption subkeys')
            [CompletionResult]::new('--overwrite', '--overwrite', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('-v', '-v', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('--verbose', '--verbose', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--batch', '--batch', [CompletionResultType]::ParameterName, 'Prevents any kind of prompting')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;decrypt' {
            [CompletionResult]::new('--output', '--output', [CompletionResultType]::ParameterName, 'Write to FILE or stdout if omitted')
            [CompletionResult]::new('--signatures', '--signatures', [CompletionResultType]::ParameterName, 'Set the threshold of valid signatures to N')
            [CompletionResult]::new('--signer', '--signer', [CompletionResultType]::ParameterName, 'Require a signature from a certificate with the specified fingerprint or key ID')
            [CompletionResult]::new('--signer-userid', '--signer-userid', [CompletionResultType]::ParameterName, 'Require a signature from a certificate with the specified user ID')
            [CompletionResult]::new('--signer-email', '--signer-email', [CompletionResultType]::ParameterName, 'Require a signature from a certificate where a user ID includes the specified email address')
            [CompletionResult]::new('--signer-domain', '--signer-domain', [CompletionResultType]::ParameterName, 'Require a signature from a certificate where a user ID includes an email address for the specified domain')
            [CompletionResult]::new('--signer-file', '--signer-file', [CompletionResultType]::ParameterName, 'Require a signature from a certificate read from PATH')
            [CompletionResult]::new('--recipient-file', '--recipient-file', [CompletionResultType]::ParameterName, 'Decrypt the message using the key in KEY_FILE')
            [CompletionResult]::new('--session-key', '--session-key', [CompletionResultType]::ParameterName, 'Decrypt an encrypted message using SESSION-KEY')
            [CompletionResult]::new('--cli-version', '--cli-version', [CompletionResultType]::ParameterName, 'Select a CLI version')
            [CompletionResult]::new('--home', '--home', [CompletionResultType]::ParameterName, 'Set the home directory')
            [CompletionResult]::new('--key-store', '--key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', '--cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--keyring', '--keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--known-notation', '--known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', '--time', [CompletionResultType]::ParameterName, 'Set the reference time as an ISO 8601 formatted timestamp')
            [CompletionResult]::new('--policy-as-of', '--policy-as-of', [CompletionResultType]::ParameterName, 'Select the cryptographic policy as of the specified time')
            [CompletionResult]::new('--trust-root', '--trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('--password-file', '--password-file', [CompletionResultType]::ParameterName, 'Seed the password cache with the specified password')
            [CompletionResult]::new('--dump-session-key', '--dump-session-key', [CompletionResultType]::ParameterName, 'Print the session key to stderr')
            [CompletionResult]::new('--overwrite', '--overwrite', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('-v', '-v', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('--verbose', '--verbose', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--batch', '--batch', [CompletionResultType]::ParameterName, 'Prevents any kind of prompting')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;sign' {
            [CompletionResult]::new('--output', '--output', [CompletionResultType]::ParameterName, 'Write to FILE or stdout if omitted')
            [CompletionResult]::new('--signature-file', '--signature-file', [CompletionResultType]::ParameterName, 'Create a detached signature file')
            [CompletionResult]::new('--mode', '--mode', [CompletionResultType]::ParameterName, 'Select the signature mode')
            [CompletionResult]::new('--merge', '--merge', [CompletionResultType]::ParameterName, 'Merge signatures from the input and SIGNED-MESSAGE')
            [CompletionResult]::new('--signer', '--signer', [CompletionResultType]::ParameterName, 'Create the signature using the key with the specified fingerprint or key ID')
            [CompletionResult]::new('--signer-userid', '--signer-userid', [CompletionResultType]::ParameterName, 'Create the signature using the key with the specified user ID')
            [CompletionResult]::new('--signer-email', '--signer-email', [CompletionResultType]::ParameterName, 'Create the signature using the key where a user ID includes the specified email address')
            [CompletionResult]::new('--signer-file', '--signer-file', [CompletionResultType]::ParameterName, 'Create the signature using the key read from PATH')
            [CompletionResult]::new('--signature-notation', '--signature-notation', [CompletionResultType]::ParameterName, 'Add a notation to the signature')
            [CompletionResult]::new('--cli-version', '--cli-version', [CompletionResultType]::ParameterName, 'Select a CLI version')
            [CompletionResult]::new('--home', '--home', [CompletionResultType]::ParameterName, 'Set the home directory')
            [CompletionResult]::new('--key-store', '--key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', '--cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--keyring', '--keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--known-notation', '--known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', '--time', [CompletionResultType]::ParameterName, 'Set the reference time as an ISO 8601 formatted timestamp')
            [CompletionResult]::new('--policy-as-of', '--policy-as-of', [CompletionResultType]::ParameterName, 'Select the cryptographic policy as of the specified time')
            [CompletionResult]::new('--trust-root', '--trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('--password-file', '--password-file', [CompletionResultType]::ParameterName, 'Seed the password cache with the specified password')
            [CompletionResult]::new('--binary', '--binary', [CompletionResultType]::ParameterName, 'Emit binary data')
            [CompletionResult]::new('--message', '--message', [CompletionResultType]::ParameterName, 'Create an inline-signed message')
            [CompletionResult]::new('--cleartext', '--cleartext', [CompletionResultType]::ParameterName, 'Create a cleartext-signed message')
            [CompletionResult]::new('--append', '--append', [CompletionResultType]::ParameterName, 'Append a signature to existing signature')
            [CompletionResult]::new('--notarize', '--notarize', [CompletionResultType]::ParameterName, 'Sign a message and all existing signatures')
            [CompletionResult]::new('--signer-self', '--signer-self', [CompletionResultType]::ParameterName, 'Sign using your default signer keys')
            [CompletionResult]::new('--overwrite', '--overwrite', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('-v', '-v', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('--verbose', '--verbose', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--batch', '--batch', [CompletionResultType]::ParameterName, 'Prevents any kind of prompting')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;verify' {
            [CompletionResult]::new('--output', '--output', [CompletionResultType]::ParameterName, 'Write to FILE or stdout if omitted')
            [CompletionResult]::new('--signature-file', '--signature-file', [CompletionResultType]::ParameterName, 'Verify a detached signature file')
            [CompletionResult]::new('--signatures', '--signatures', [CompletionResultType]::ParameterName, 'Set the threshold of valid signatures to N')
            [CompletionResult]::new('--signer', '--signer', [CompletionResultType]::ParameterName, 'Require a signature from a certificate with the specified fingerprint or key ID')
            [CompletionResult]::new('--signer-userid', '--signer-userid', [CompletionResultType]::ParameterName, 'Require a signature from a certificate with the specified user ID')
            [CompletionResult]::new('--signer-email', '--signer-email', [CompletionResultType]::ParameterName, 'Require a signature from a certificate where a user ID includes the specified email address')
            [CompletionResult]::new('--signer-domain', '--signer-domain', [CompletionResultType]::ParameterName, 'Require a signature from a certificate where a user ID includes an email address for the specified domain')
            [CompletionResult]::new('--signer-file', '--signer-file', [CompletionResultType]::ParameterName, 'Require a signature from a certificate read from PATH')
            [CompletionResult]::new('--cli-version', '--cli-version', [CompletionResultType]::ParameterName, 'Select a CLI version')
            [CompletionResult]::new('--home', '--home', [CompletionResultType]::ParameterName, 'Set the home directory')
            [CompletionResult]::new('--key-store', '--key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', '--cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--keyring', '--keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--known-notation', '--known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', '--time', [CompletionResultType]::ParameterName, 'Set the reference time as an ISO 8601 formatted timestamp')
            [CompletionResult]::new('--policy-as-of', '--policy-as-of', [CompletionResultType]::ParameterName, 'Select the cryptographic policy as of the specified time')
            [CompletionResult]::new('--trust-root', '--trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('--password-file', '--password-file', [CompletionResultType]::ParameterName, 'Seed the password cache with the specified password')
            [CompletionResult]::new('--message', '--message', [CompletionResultType]::ParameterName, 'Verify an inline signed message')
            [CompletionResult]::new('--cleartext', '--cleartext', [CompletionResultType]::ParameterName, 'Verify a cleartext-signed message')
            [CompletionResult]::new('--overwrite', '--overwrite', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('-v', '-v', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('--verbose', '--verbose', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--batch', '--batch', [CompletionResultType]::ParameterName, 'Prevents any kind of prompting')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;download' {
            [CompletionResult]::new('--url', '--url', [CompletionResultType]::ParameterName, 'The data to download')
            [CompletionResult]::new('--signature-url', '--signature-url', [CompletionResultType]::ParameterName, 'URL of the signature')
            [CompletionResult]::new('--signer', '--signer', [CompletionResultType]::ParameterName, 'Require a signature from a certificate with the specified fingerprint or key ID')
            [CompletionResult]::new('--signer-userid', '--signer-userid', [CompletionResultType]::ParameterName, 'Require a signature from a certificate with the specified user ID')
            [CompletionResult]::new('--signer-email', '--signer-email', [CompletionResultType]::ParameterName, 'Require a signature from a certificate where a user ID includes the specified email address')
            [CompletionResult]::new('--signer-domain', '--signer-domain', [CompletionResultType]::ParameterName, 'Require a signature from a certificate where a user ID includes an email address for the specified domain')
            [CompletionResult]::new('--signer-file', '--signer-file', [CompletionResultType]::ParameterName, 'Require a signature from a certificate read from PATH')
            [CompletionResult]::new('--signatures', '--signatures', [CompletionResultType]::ParameterName, 'Set the threshold of valid signatures to N')
            [CompletionResult]::new('--output', '--output', [CompletionResultType]::ParameterName, 'Write to FILE or stdout if FILE is ''-''')
            [CompletionResult]::new('--cli-version', '--cli-version', [CompletionResultType]::ParameterName, 'Select a CLI version')
            [CompletionResult]::new('--home', '--home', [CompletionResultType]::ParameterName, 'Set the home directory')
            [CompletionResult]::new('--key-store', '--key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', '--cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--keyring', '--keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--known-notation', '--known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', '--time', [CompletionResultType]::ParameterName, 'Set the reference time as an ISO 8601 formatted timestamp')
            [CompletionResult]::new('--policy-as-of', '--policy-as-of', [CompletionResultType]::ParameterName, 'Select the cryptographic policy as of the specified time')
            [CompletionResult]::new('--trust-root', '--trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('--password-file', '--password-file', [CompletionResultType]::ParameterName, 'Seed the password cache with the specified password')
            [CompletionResult]::new('--message', '--message', [CompletionResultType]::ParameterName, 'Verify an inline signed message')
            [CompletionResult]::new('--cleartext', '--cleartext', [CompletionResultType]::ParameterName, 'Verify a cleartext-signed message')
            [CompletionResult]::new('--overwrite', '--overwrite', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('-v', '-v', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('--verbose', '--verbose', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--batch', '--batch', [CompletionResultType]::ParameterName, 'Prevents any kind of prompting')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;inspect' {
            [CompletionResult]::new('--cert', '--cert', [CompletionResultType]::ParameterName, 'Inspect certificates with the specified fingerprint or key ID')
            [CompletionResult]::new('--cert-userid', '--cert-userid', [CompletionResultType]::ParameterName, 'Inspect certificates with the specified user ID (note: User IDs are not authenticated)')
            [CompletionResult]::new('--cert-email', '--cert-email', [CompletionResultType]::ParameterName, 'Inspect certificates where a user ID includes the specified email address (note: User IDs are not authenticated)')
            [CompletionResult]::new('--cert-domain', '--cert-domain', [CompletionResultType]::ParameterName, 'Inspect certificates where a user ID includes an email address for the specified domain (note: User IDs are not authenticated)')
            [CompletionResult]::new('--cert-grep', '--cert-grep', [CompletionResultType]::ParameterName, 'Inspect certificates with a user ID that matches the pattern, case insensitively (note: User IDs are not authenticated)')
            [CompletionResult]::new('--cert-file', '--cert-file', [CompletionResultType]::ParameterName, 'Read certificates from PATH')
            [CompletionResult]::new('--cli-version', '--cli-version', [CompletionResultType]::ParameterName, 'Select a CLI version')
            [CompletionResult]::new('--home', '--home', [CompletionResultType]::ParameterName, 'Set the home directory')
            [CompletionResult]::new('--key-store', '--key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', '--cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--keyring', '--keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--known-notation', '--known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', '--time', [CompletionResultType]::ParameterName, 'Set the reference time as an ISO 8601 formatted timestamp')
            [CompletionResult]::new('--policy-as-of', '--policy-as-of', [CompletionResultType]::ParameterName, 'Select the cryptographic policy as of the specified time')
            [CompletionResult]::new('--trust-root', '--trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('--password-file', '--password-file', [CompletionResultType]::ParameterName, 'Seed the password cache with the specified password')
            [CompletionResult]::new('--certifications', '--certifications', [CompletionResultType]::ParameterName, 'Print third-party certifications')
            [CompletionResult]::new('--dump-bad-signatures', '--dump-bad-signatures', [CompletionResultType]::ParameterName, 'Dump signatures that are definitively bad')
            [CompletionResult]::new('--overwrite', '--overwrite', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('-v', '-v', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('--verbose', '--verbose', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--batch', '--batch', [CompletionResultType]::ParameterName, 'Prevents any kind of prompting')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;cert' {
            [CompletionResult]::new('--cli-version', '--cli-version', [CompletionResultType]::ParameterName, 'Select a CLI version')
            [CompletionResult]::new('--home', '--home', [CompletionResultType]::ParameterName, 'Set the home directory')
            [CompletionResult]::new('--key-store', '--key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', '--cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--keyring', '--keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--known-notation', '--known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', '--time', [CompletionResultType]::ParameterName, 'Set the reference time as an ISO 8601 formatted timestamp')
            [CompletionResult]::new('--policy-as-of', '--policy-as-of', [CompletionResultType]::ParameterName, 'Select the cryptographic policy as of the specified time')
            [CompletionResult]::new('--trust-root', '--trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('--password-file', '--password-file', [CompletionResultType]::ParameterName, 'Seed the password cache with the specified password')
            [CompletionResult]::new('--overwrite', '--overwrite', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('-v', '-v', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('--verbose', '--verbose', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--batch', '--batch', [CompletionResultType]::ParameterName, 'Prevents any kind of prompting')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('import', 'import', [CompletionResultType]::ParameterValue, 'Import certificates into the local certificate store')
            [CompletionResult]::new('export', 'export', [CompletionResultType]::ParameterValue, 'Export certificates from the local certificate store')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List certificates and user IDs')
            [CompletionResult]::new('lint', 'lint', [CompletionResultType]::ParameterValue, 'Check certificates for issues')
            break
        }
        'sq;cert;import' {
            [CompletionResult]::new('--cli-version', '--cli-version', [CompletionResultType]::ParameterName, 'Select a CLI version')
            [CompletionResult]::new('--home', '--home', [CompletionResultType]::ParameterName, 'Set the home directory')
            [CompletionResult]::new('--key-store', '--key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', '--cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--keyring', '--keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--known-notation', '--known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', '--time', [CompletionResultType]::ParameterName, 'Set the reference time as an ISO 8601 formatted timestamp')
            [CompletionResult]::new('--policy-as-of', '--policy-as-of', [CompletionResultType]::ParameterName, 'Select the cryptographic policy as of the specified time')
            [CompletionResult]::new('--trust-root', '--trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('--password-file', '--password-file', [CompletionResultType]::ParameterName, 'Seed the password cache with the specified password')
            [CompletionResult]::new('--overwrite', '--overwrite', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('-v', '-v', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('--verbose', '--verbose', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--batch', '--batch', [CompletionResultType]::ParameterName, 'Prevents any kind of prompting')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;cert;export' {
            [CompletionResult]::new('--output', '--output', [CompletionResultType]::ParameterName, 'Write to FILE or stdout if omitted')
            [CompletionResult]::new('--cert', '--cert', [CompletionResultType]::ParameterName, 'Use certificates with the specified fingerprint or key ID')
            [CompletionResult]::new('--cert-userid', '--cert-userid', [CompletionResultType]::ParameterName, 'Use certificates with the specified user ID')
            [CompletionResult]::new('--cert-email', '--cert-email', [CompletionResultType]::ParameterName, 'Use certificates where a user ID includes the specified email address')
            [CompletionResult]::new('--cert-domain', '--cert-domain', [CompletionResultType]::ParameterName, 'Use certificates where a user ID includes an email address for the specified domain')
            [CompletionResult]::new('--cert-grep', '--cert-grep', [CompletionResultType]::ParameterName, 'Use certificates with a user ID that matches the pattern, case insensitively')
            [CompletionResult]::new('--cli-version', '--cli-version', [CompletionResultType]::ParameterName, 'Select a CLI version')
            [CompletionResult]::new('--home', '--home', [CompletionResultType]::ParameterName, 'Set the home directory')
            [CompletionResult]::new('--key-store', '--key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', '--cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--keyring', '--keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--known-notation', '--known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', '--time', [CompletionResultType]::ParameterName, 'Set the reference time as an ISO 8601 formatted timestamp')
            [CompletionResult]::new('--policy-as-of', '--policy-as-of', [CompletionResultType]::ParameterName, 'Select the cryptographic policy as of the specified time')
            [CompletionResult]::new('--trust-root', '--trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('--password-file', '--password-file', [CompletionResultType]::ParameterName, 'Seed the password cache with the specified password')
            [CompletionResult]::new('--local', '--local', [CompletionResultType]::ParameterName, 'Export local (non-exportable) signatures')
            [CompletionResult]::new('--all', '--all', [CompletionResultType]::ParameterName, 'Export all certificates')
            [CompletionResult]::new('--overwrite', '--overwrite', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('-v', '-v', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('--verbose', '--verbose', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--batch', '--batch', [CompletionResultType]::ParameterName, 'Prevents any kind of prompting')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;cert;list' {
            [CompletionResult]::new('--cert', '--cert', [CompletionResultType]::ParameterName, 'List certificates with the specified fingerprint or key ID')
            [CompletionResult]::new('--cert-userid', '--cert-userid', [CompletionResultType]::ParameterName, 'List bindings with the specified user ID')
            [CompletionResult]::new('--cert-email', '--cert-email', [CompletionResultType]::ParameterName, 'List bindings with user IDs that contain the specified email address')
            [CompletionResult]::new('--cert-domain', '--cert-domain', [CompletionResultType]::ParameterName, 'List bindings with user IDs that contain an email address in the specified domain')
            [CompletionResult]::new('--cert-grep', '--cert-grep', [CompletionResultType]::ParameterName, 'List bindings with a user ID that contains the pattern')
            [CompletionResult]::new('--amount', '--amount', [CompletionResultType]::ParameterName, 'The required amount of trust')
            [CompletionResult]::new('--cli-version', '--cli-version', [CompletionResultType]::ParameterName, 'Select a CLI version')
            [CompletionResult]::new('--home', '--home', [CompletionResultType]::ParameterName, 'Set the home directory')
            [CompletionResult]::new('--key-store', '--key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', '--cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--keyring', '--keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--known-notation', '--known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', '--time', [CompletionResultType]::ParameterName, 'Set the reference time as an ISO 8601 formatted timestamp')
            [CompletionResult]::new('--policy-as-of', '--policy-as-of', [CompletionResultType]::ParameterName, 'Select the cryptographic policy as of the specified time')
            [CompletionResult]::new('--trust-root', '--trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('--password-file', '--password-file', [CompletionResultType]::ParameterName, 'Seed the password cache with the specified password')
            [CompletionResult]::new('--show-paths', '--show-paths', [CompletionResultType]::ParameterName, 'Show why a binding is authenticated')
            [CompletionResult]::new('--gossip', '--gossip', [CompletionResultType]::ParameterName, 'Treats all certificates as unreliable trust roots')
            [CompletionResult]::new('--unusable', '--unusable', [CompletionResultType]::ParameterName, 'Show bindings that are unusable')
            [CompletionResult]::new('--certification-network', '--certification-network', [CompletionResultType]::ParameterName, 'Treats the network as a certification network')
            [CompletionResult]::new('--overwrite', '--overwrite', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('-v', '-v', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('--verbose', '--verbose', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--batch', '--batch', [CompletionResultType]::ParameterName, 'Prevents any kind of prompting')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;cert;lint' {
            [CompletionResult]::new('--cert', '--cert', [CompletionResultType]::ParameterName, 'Use certificates with the specified fingerprint or key ID')
            [CompletionResult]::new('--cert-userid', '--cert-userid', [CompletionResultType]::ParameterName, 'Use certificates with the specified user ID')
            [CompletionResult]::new('--cert-email', '--cert-email', [CompletionResultType]::ParameterName, 'Use certificates where a user ID includes the specified email address')
            [CompletionResult]::new('--cert-domain', '--cert-domain', [CompletionResultType]::ParameterName, 'Use certificates where a user ID includes an email address for the specified domain')
            [CompletionResult]::new('--cert-grep', '--cert-grep', [CompletionResultType]::ParameterName, 'Use certificates with a user ID that matches the pattern, case insensitively')
            [CompletionResult]::new('--cert-file', '--cert-file', [CompletionResultType]::ParameterName, 'Read certificates from PATH')
            [CompletionResult]::new('--output', '--output', [CompletionResultType]::ParameterName, 'Write to the specified FILE')
            [CompletionResult]::new('--cli-version', '--cli-version', [CompletionResultType]::ParameterName, 'Select a CLI version')
            [CompletionResult]::new('--home', '--home', [CompletionResultType]::ParameterName, 'Set the home directory')
            [CompletionResult]::new('--key-store', '--key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', '--cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--keyring', '--keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--known-notation', '--known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', '--time', [CompletionResultType]::ParameterName, 'Set the reference time as an ISO 8601 formatted timestamp')
            [CompletionResult]::new('--policy-as-of', '--policy-as-of', [CompletionResultType]::ParameterName, 'Select the cryptographic policy as of the specified time')
            [CompletionResult]::new('--trust-root', '--trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('--password-file', '--password-file', [CompletionResultType]::ParameterName, 'Seed the password cache with the specified password')
            [CompletionResult]::new('--fix', '--fix', [CompletionResultType]::ParameterName, 'Attempts to fix certificates, when possible')
            [CompletionResult]::new('--overwrite', '--overwrite', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('-v', '-v', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('--verbose', '--verbose', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--batch', '--batch', [CompletionResultType]::ParameterName, 'Prevents any kind of prompting')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;key' {
            [CompletionResult]::new('--cli-version', '--cli-version', [CompletionResultType]::ParameterName, 'Select a CLI version')
            [CompletionResult]::new('--home', '--home', [CompletionResultType]::ParameterName, 'Set the home directory')
            [CompletionResult]::new('--key-store', '--key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', '--cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--keyring', '--keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--known-notation', '--known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', '--time', [CompletionResultType]::ParameterName, 'Set the reference time as an ISO 8601 formatted timestamp')
            [CompletionResult]::new('--policy-as-of', '--policy-as-of', [CompletionResultType]::ParameterName, 'Select the cryptographic policy as of the specified time')
            [CompletionResult]::new('--trust-root', '--trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('--password-file', '--password-file', [CompletionResultType]::ParameterName, 'Seed the password cache with the specified password')
            [CompletionResult]::new('--overwrite', '--overwrite', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('-v', '-v', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('--verbose', '--verbose', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--batch', '--batch', [CompletionResultType]::ParameterName, 'Prevents any kind of prompting')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List keys managed by the key store')
            [CompletionResult]::new('generate', 'generate', [CompletionResultType]::ParameterValue, 'Generate a new key')
            [CompletionResult]::new('rotate', 'rotate', [CompletionResultType]::ParameterValue, 'Rotate a certificate')
            [CompletionResult]::new('import', 'import', [CompletionResultType]::ParameterValue, 'Import keys into the key store')
            [CompletionResult]::new('export', 'export', [CompletionResultType]::ParameterValue, 'Export keys from the key store')
            [CompletionResult]::new('delete', 'delete', [CompletionResultType]::ParameterValue, 'Delete a certificate''s secret key material')
            [CompletionResult]::new('password', 'password', [CompletionResultType]::ParameterValue, 'Change the password protecting secret key material')
            [CompletionResult]::new('expire', 'expire', [CompletionResultType]::ParameterValue, 'Change a certificate''s expiration time')
            [CompletionResult]::new('revoke', 'revoke', [CompletionResultType]::ParameterValue, 'Revoke a certificate')
            [CompletionResult]::new('userid', 'userid', [CompletionResultType]::ParameterValue, 'Manage User IDs')
            [CompletionResult]::new('subkey', 'subkey', [CompletionResultType]::ParameterValue, 'Manage subkeys')
            [CompletionResult]::new('approvals', 'approvals', [CompletionResultType]::ParameterValue, 'Manages certification approvals')
            break
        }
        'sq;key;list' {
            [CompletionResult]::new('--cert', '--cert', [CompletionResultType]::ParameterName, 'List keys with the specified fingerprint or key ID')
            [CompletionResult]::new('--cert-userid', '--cert-userid', [CompletionResultType]::ParameterName, 'List keys with the specified user ID')
            [CompletionResult]::new('--cert-email', '--cert-email', [CompletionResultType]::ParameterName, 'List keys where a user ID includes the specified email address')
            [CompletionResult]::new('--cert-domain', '--cert-domain', [CompletionResultType]::ParameterName, 'List keys where a user ID includes an email address for the specified domain')
            [CompletionResult]::new('--cert-grep', '--cert-grep', [CompletionResultType]::ParameterName, 'List keys with a user ID that matches the pattern, case insensitively')
            [CompletionResult]::new('--cli-version', '--cli-version', [CompletionResultType]::ParameterName, 'Select a CLI version')
            [CompletionResult]::new('--home', '--home', [CompletionResultType]::ParameterName, 'Set the home directory')
            [CompletionResult]::new('--key-store', '--key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', '--cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--keyring', '--keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--known-notation', '--known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', '--time', [CompletionResultType]::ParameterName, 'Set the reference time as an ISO 8601 formatted timestamp')
            [CompletionResult]::new('--policy-as-of', '--policy-as-of', [CompletionResultType]::ParameterName, 'Select the cryptographic policy as of the specified time')
            [CompletionResult]::new('--trust-root', '--trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('--password-file', '--password-file', [CompletionResultType]::ParameterName, 'Seed the password cache with the specified password')
            [CompletionResult]::new('--overwrite', '--overwrite', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('-v', '-v', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('--verbose', '--verbose', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--batch', '--batch', [CompletionResultType]::ParameterName, 'Prevents any kind of prompting')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;key;generate' {
            [CompletionResult]::new('--name', '--name', [CompletionResultType]::ParameterName, 'Add a name as user ID to the key')
            [CompletionResult]::new('--email', '--email', [CompletionResultType]::ParameterName, 'Add an email address as user ID to the key')
            [CompletionResult]::new('--userid', '--userid', [CompletionResultType]::ParameterName, 'Add a user ID to the key')
            [CompletionResult]::new('--cipher-suite', '--cipher-suite', [CompletionResultType]::ParameterName, 'Select the cryptographic algorithms for the key')
            [CompletionResult]::new('--profile', '--profile', [CompletionResultType]::ParameterName, 'Select the OpenPGP standard for the key')
            [CompletionResult]::new('--new-password-file', '--new-password-file', [CompletionResultType]::ParameterName, 'File containing password to encrypt the secret key material')
            [CompletionResult]::new('--can-encrypt', '--can-encrypt', [CompletionResultType]::ParameterName, 'Add an encryption-capable subkey [default: universal]')
            [CompletionResult]::new('--output', '--output', [CompletionResultType]::ParameterName, 'Write the key to the specified file')
            [CompletionResult]::new('--rev-cert', '--rev-cert', [CompletionResultType]::ParameterName, 'Write the emergency revocation certificate to FILE')
            [CompletionResult]::new('--expiration', '--expiration', [CompletionResultType]::ParameterName, 'Sets the expiration time')
            [CompletionResult]::new('--cli-version', '--cli-version', [CompletionResultType]::ParameterName, 'Select a CLI version')
            [CompletionResult]::new('--home', '--home', [CompletionResultType]::ParameterName, 'Set the home directory')
            [CompletionResult]::new('--key-store', '--key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', '--cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--keyring', '--keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--known-notation', '--known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', '--time', [CompletionResultType]::ParameterName, 'Set the reference time as an ISO 8601 formatted timestamp')
            [CompletionResult]::new('--policy-as-of', '--policy-as-of', [CompletionResultType]::ParameterName, 'Select the cryptographic policy as of the specified time')
            [CompletionResult]::new('--trust-root', '--trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('--password-file', '--password-file', [CompletionResultType]::ParameterName, 'Seed the password cache with the specified password')
            [CompletionResult]::new('--own-key', '--own-key', [CompletionResultType]::ParameterName, 'Mark the key as one''s own key')
            [CompletionResult]::new('--shared-key', '--shared-key', [CompletionResultType]::ParameterName, 'Mark the key as a shared key')
            [CompletionResult]::new('--allow-non-canonical-userids', '--allow-non-canonical-userids', [CompletionResultType]::ParameterName, 'Don''t reject user IDs that are not in canonical form')
            [CompletionResult]::new('--no-userids', '--no-userids', [CompletionResultType]::ParameterName, 'Create a key without any user IDs')
            [CompletionResult]::new('--without-password', '--without-password', [CompletionResultType]::ParameterName, 'Don''t protect the secret key material with a password')
            [CompletionResult]::new('--can-sign', '--can-sign', [CompletionResultType]::ParameterName, 'Add a signing-capable subkey (default)')
            [CompletionResult]::new('--cannot-sign', '--cannot-sign', [CompletionResultType]::ParameterName, 'Don''t add a signing-capable subkey')
            [CompletionResult]::new('--can-authenticate', '--can-authenticate', [CompletionResultType]::ParameterName, 'Add an authentication-capable subkey (default)')
            [CompletionResult]::new('--cannot-authenticate', '--cannot-authenticate', [CompletionResultType]::ParameterName, 'Don''t add an authentication-capable subkey')
            [CompletionResult]::new('--cannot-encrypt', '--cannot-encrypt', [CompletionResultType]::ParameterName, 'Don''t add an encryption-capable subkey')
            [CompletionResult]::new('--overwrite', '--overwrite', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('-v', '-v', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('--verbose', '--verbose', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--batch', '--batch', [CompletionResultType]::ParameterName, 'Prevents any kind of prompting')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;key;rotate' {
            [CompletionResult]::new('--cert', '--cert', [CompletionResultType]::ParameterName, 'Use certificates with the specified fingerprint or key ID')
            [CompletionResult]::new('--cert-userid', '--cert-userid', [CompletionResultType]::ParameterName, 'Use certificates with the specified user ID')
            [CompletionResult]::new('--cert-email', '--cert-email', [CompletionResultType]::ParameterName, 'Use certificates where a user ID includes the specified email address')
            [CompletionResult]::new('--cert-file', '--cert-file', [CompletionResultType]::ParameterName, 'Read certificates from PATH')
            [CompletionResult]::new('--cipher-suite', '--cipher-suite', [CompletionResultType]::ParameterName, 'Select the cryptographic algorithms for the key')
            [CompletionResult]::new('--profile', '--profile', [CompletionResultType]::ParameterName, 'Select the OpenPGP standard for the key')
            [CompletionResult]::new('--new-password-file', '--new-password-file', [CompletionResultType]::ParameterName, 'File containing password to encrypt the secret key material')
            [CompletionResult]::new('--can-encrypt', '--can-encrypt', [CompletionResultType]::ParameterName, 'Add an encryption-capable subkey')
            [CompletionResult]::new('--output', '--output', [CompletionResultType]::ParameterName, 'Write the key to the specified file')
            [CompletionResult]::new('--rev-cert', '--rev-cert', [CompletionResultType]::ParameterName, 'Write the emergency revocation certificate to FILE')
            [CompletionResult]::new('--expiration', '--expiration', [CompletionResultType]::ParameterName, 'Sets the expiration time')
            [CompletionResult]::new('--retire-in', '--retire-in', [CompletionResultType]::ParameterName, 'Sets the time at which the certificate should be retired')
            [CompletionResult]::new('--cli-version', '--cli-version', [CompletionResultType]::ParameterName, 'Select a CLI version')
            [CompletionResult]::new('--home', '--home', [CompletionResultType]::ParameterName, 'Set the home directory')
            [CompletionResult]::new('--key-store', '--key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', '--cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--keyring', '--keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--known-notation', '--known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', '--time', [CompletionResultType]::ParameterName, 'Set the reference time as an ISO 8601 formatted timestamp')
            [CompletionResult]::new('--policy-as-of', '--policy-as-of', [CompletionResultType]::ParameterName, 'Select the cryptographic policy as of the specified time')
            [CompletionResult]::new('--trust-root', '--trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('--password-file', '--password-file', [CompletionResultType]::ParameterName, 'Seed the password cache with the specified password')
            [CompletionResult]::new('--own-key', '--own-key', [CompletionResultType]::ParameterName, 'Mark the key as one''s own key')
            [CompletionResult]::new('--shared-key', '--shared-key', [CompletionResultType]::ParameterName, 'Mark the key as a shared key')
            [CompletionResult]::new('--without-password', '--without-password', [CompletionResultType]::ParameterName, 'Don''t protect the secret key material with a password')
            [CompletionResult]::new('--can-sign', '--can-sign', [CompletionResultType]::ParameterName, 'Add a signing-capable subkey')
            [CompletionResult]::new('--cannot-sign', '--cannot-sign', [CompletionResultType]::ParameterName, 'Don''t add a signing-capable subkey')
            [CompletionResult]::new('--can-authenticate', '--can-authenticate', [CompletionResultType]::ParameterName, 'Add an authentication-capable subkey')
            [CompletionResult]::new('--cannot-authenticate', '--cannot-authenticate', [CompletionResultType]::ParameterName, 'Don''t add an authentication-capable subkey')
            [CompletionResult]::new('--cannot-encrypt', '--cannot-encrypt', [CompletionResultType]::ParameterName, 'Don''t add an encryption-capable subkey')
            [CompletionResult]::new('--overwrite', '--overwrite', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('-v', '-v', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('--verbose', '--verbose', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--batch', '--batch', [CompletionResultType]::ParameterName, 'Prevents any kind of prompting')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;key;import' {
            [CompletionResult]::new('--cli-version', '--cli-version', [CompletionResultType]::ParameterName, 'Select a CLI version')
            [CompletionResult]::new('--home', '--home', [CompletionResultType]::ParameterName, 'Set the home directory')
            [CompletionResult]::new('--key-store', '--key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', '--cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--keyring', '--keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--known-notation', '--known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', '--time', [CompletionResultType]::ParameterName, 'Set the reference time as an ISO 8601 formatted timestamp')
            [CompletionResult]::new('--policy-as-of', '--policy-as-of', [CompletionResultType]::ParameterName, 'Select the cryptographic policy as of the specified time')
            [CompletionResult]::new('--trust-root', '--trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('--password-file', '--password-file', [CompletionResultType]::ParameterName, 'Seed the password cache with the specified password')
            [CompletionResult]::new('--overwrite', '--overwrite', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('-v', '-v', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('--verbose', '--verbose', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--batch', '--batch', [CompletionResultType]::ParameterName, 'Prevents any kind of prompting')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;key;export' {
            [CompletionResult]::new('--cert', '--cert', [CompletionResultType]::ParameterName, 'Export keys with the specified fingerprint or key ID')
            [CompletionResult]::new('--cert-userid', '--cert-userid', [CompletionResultType]::ParameterName, 'Export keys with the specified user ID')
            [CompletionResult]::new('--cert-email', '--cert-email', [CompletionResultType]::ParameterName, 'Export keys where a user ID includes the specified email address')
            [CompletionResult]::new('--cert-domain', '--cert-domain', [CompletionResultType]::ParameterName, 'Export keys where a user ID includes an email address for the specified domain')
            [CompletionResult]::new('--cert-grep', '--cert-grep', [CompletionResultType]::ParameterName, 'Export keys with a user ID that matches the pattern, case insensitively')
            [CompletionResult]::new('--output', '--output', [CompletionResultType]::ParameterName, 'Write to FILE or stdout if omitted')
            [CompletionResult]::new('--cli-version', '--cli-version', [CompletionResultType]::ParameterName, 'Select a CLI version')
            [CompletionResult]::new('--home', '--home', [CompletionResultType]::ParameterName, 'Set the home directory')
            [CompletionResult]::new('--key-store', '--key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', '--cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--keyring', '--keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--known-notation', '--known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', '--time', [CompletionResultType]::ParameterName, 'Set the reference time as an ISO 8601 formatted timestamp')
            [CompletionResult]::new('--policy-as-of', '--policy-as-of', [CompletionResultType]::ParameterName, 'Select the cryptographic policy as of the specified time')
            [CompletionResult]::new('--trust-root', '--trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('--password-file', '--password-file', [CompletionResultType]::ParameterName, 'Seed the password cache with the specified password')
            [CompletionResult]::new('--overwrite', '--overwrite', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('-v', '-v', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('--verbose', '--verbose', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--batch', '--batch', [CompletionResultType]::ParameterName, 'Prevents any kind of prompting')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;key;delete' {
            [CompletionResult]::new('--cert', '--cert', [CompletionResultType]::ParameterName, 'Delete secret key material from the key with the specified fingerprint or key ID')
            [CompletionResult]::new('--cert-userid', '--cert-userid', [CompletionResultType]::ParameterName, 'Delete secret key material from the key with the specified user ID')
            [CompletionResult]::new('--cert-email', '--cert-email', [CompletionResultType]::ParameterName, 'Delete secret key material from the key where a user ID includes the specified email address')
            [CompletionResult]::new('--cert-file', '--cert-file', [CompletionResultType]::ParameterName, 'Delete the secret key material from the key read from PATH')
            [CompletionResult]::new('--output', '--output', [CompletionResultType]::ParameterName, 'Write the stripped certificate to the specified file')
            [CompletionResult]::new('--cli-version', '--cli-version', [CompletionResultType]::ParameterName, 'Select a CLI version')
            [CompletionResult]::new('--home', '--home', [CompletionResultType]::ParameterName, 'Set the home directory')
            [CompletionResult]::new('--key-store', '--key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', '--cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--keyring', '--keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--known-notation', '--known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', '--time', [CompletionResultType]::ParameterName, 'Set the reference time as an ISO 8601 formatted timestamp')
            [CompletionResult]::new('--policy-as-of', '--policy-as-of', [CompletionResultType]::ParameterName, 'Select the cryptographic policy as of the specified time')
            [CompletionResult]::new('--trust-root', '--trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('--password-file', '--password-file', [CompletionResultType]::ParameterName, 'Seed the password cache with the specified password')
            [CompletionResult]::new('--overwrite', '--overwrite', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('-v', '-v', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('--verbose', '--verbose', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--batch', '--batch', [CompletionResultType]::ParameterName, 'Prevents any kind of prompting')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;key;password' {
            [CompletionResult]::new('--cert', '--cert', [CompletionResultType]::ParameterName, 'Change the password for the secret key material from the key with the specified fingerprint or key ID')
            [CompletionResult]::new('--cert-userid', '--cert-userid', [CompletionResultType]::ParameterName, 'Change the password for the secret key material from the key with the specified user ID')
            [CompletionResult]::new('--cert-email', '--cert-email', [CompletionResultType]::ParameterName, 'Change the password for the secret key material from the key where a user ID includes the specified email address')
            [CompletionResult]::new('--cert-file', '--cert-file', [CompletionResultType]::ParameterName, 'Change the password for the secret key material from the key read from PATH')
            [CompletionResult]::new('--new-password-file', '--new-password-file', [CompletionResultType]::ParameterName, 'File containing password to encrypt the secret key material')
            [CompletionResult]::new('--output', '--output', [CompletionResultType]::ParameterName, 'Write to FILE or stdout if omitted')
            [CompletionResult]::new('--cli-version', '--cli-version', [CompletionResultType]::ParameterName, 'Select a CLI version')
            [CompletionResult]::new('--home', '--home', [CompletionResultType]::ParameterName, 'Set the home directory')
            [CompletionResult]::new('--key-store', '--key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', '--cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--keyring', '--keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--known-notation', '--known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', '--time', [CompletionResultType]::ParameterName, 'Set the reference time as an ISO 8601 formatted timestamp')
            [CompletionResult]::new('--policy-as-of', '--policy-as-of', [CompletionResultType]::ParameterName, 'Select the cryptographic policy as of the specified time')
            [CompletionResult]::new('--trust-root', '--trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('--password-file', '--password-file', [CompletionResultType]::ParameterName, 'Seed the password cache with the specified password')
            [CompletionResult]::new('--clear-password', '--clear-password', [CompletionResultType]::ParameterName, 'Clear the password protecting the secret key material')
            [CompletionResult]::new('--overwrite', '--overwrite', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('-v', '-v', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('--verbose', '--verbose', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--batch', '--batch', [CompletionResultType]::ParameterName, 'Prevents any kind of prompting')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;key;expire' {
            [CompletionResult]::new('--cert', '--cert', [CompletionResultType]::ParameterName, 'Change the expiration of the key with the specified fingerprint or key ID')
            [CompletionResult]::new('--cert-userid', '--cert-userid', [CompletionResultType]::ParameterName, 'Change the expiration of the key with the specified user ID')
            [CompletionResult]::new('--cert-email', '--cert-email', [CompletionResultType]::ParameterName, 'Change the expiration of the key where a user ID includes the specified email address')
            [CompletionResult]::new('--cert-file', '--cert-file', [CompletionResultType]::ParameterName, 'Change the expiration of the key read from PATH')
            [CompletionResult]::new('--output', '--output', [CompletionResultType]::ParameterName, 'Write to FILE or stdout if omitted')
            [CompletionResult]::new('--expiration', '--expiration', [CompletionResultType]::ParameterName, 'Sets the expiration time')
            [CompletionResult]::new('--cli-version', '--cli-version', [CompletionResultType]::ParameterName, 'Select a CLI version')
            [CompletionResult]::new('--home', '--home', [CompletionResultType]::ParameterName, 'Set the home directory')
            [CompletionResult]::new('--key-store', '--key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', '--cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--keyring', '--keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--known-notation', '--known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', '--time', [CompletionResultType]::ParameterName, 'Set the reference time as an ISO 8601 formatted timestamp')
            [CompletionResult]::new('--policy-as-of', '--policy-as-of', [CompletionResultType]::ParameterName, 'Select the cryptographic policy as of the specified time')
            [CompletionResult]::new('--trust-root', '--trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('--password-file', '--password-file', [CompletionResultType]::ParameterName, 'Seed the password cache with the specified password')
            [CompletionResult]::new('--overwrite', '--overwrite', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('-v', '-v', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('--verbose', '--verbose', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--batch', '--batch', [CompletionResultType]::ParameterName, 'Prevents any kind of prompting')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;key;revoke' {
            [CompletionResult]::new('--cert', '--cert', [CompletionResultType]::ParameterName, 'Revoke the key with the specified fingerprint or key ID')
            [CompletionResult]::new('--cert-userid', '--cert-userid', [CompletionResultType]::ParameterName, 'Revoke the key with the specified user ID')
            [CompletionResult]::new('--cert-email', '--cert-email', [CompletionResultType]::ParameterName, 'Revoke the key where a user ID includes the specified email address')
            [CompletionResult]::new('--cert-file', '--cert-file', [CompletionResultType]::ParameterName, 'Revoke the key read from PATH')
            [CompletionResult]::new('--revoker', '--revoker', [CompletionResultType]::ParameterName, 'Use key with the specified fingerprint or key ID to create the revocation certificate')
            [CompletionResult]::new('--revoker-userid', '--revoker-userid', [CompletionResultType]::ParameterName, 'Use key with the specified user ID to create the revocation certificate')
            [CompletionResult]::new('--revoker-email', '--revoker-email', [CompletionResultType]::ParameterName, 'Use key where a user ID includes the specified email address to create the revocation certificate')
            [CompletionResult]::new('--revoker-file', '--revoker-file', [CompletionResultType]::ParameterName, 'Read key from PATH to create the revocation certificate')
            [CompletionResult]::new('--reason', '--reason', [CompletionResultType]::ParameterName, 'The reason for the revocation')
            [CompletionResult]::new('--message', '--message', [CompletionResultType]::ParameterName, 'A short, explanatory text')
            [CompletionResult]::new('--signature-notation', '--signature-notation', [CompletionResultType]::ParameterName, 'Add a notation to the signature')
            [CompletionResult]::new('--output', '--output', [CompletionResultType]::ParameterName, 'Write to the specified FILE')
            [CompletionResult]::new('--cli-version', '--cli-version', [CompletionResultType]::ParameterName, 'Select a CLI version')
            [CompletionResult]::new('--home', '--home', [CompletionResultType]::ParameterName, 'Set the home directory')
            [CompletionResult]::new('--key-store', '--key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', '--cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--keyring', '--keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--known-notation', '--known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', '--time', [CompletionResultType]::ParameterName, 'Set the reference time as an ISO 8601 formatted timestamp')
            [CompletionResult]::new('--policy-as-of', '--policy-as-of', [CompletionResultType]::ParameterName, 'Select the cryptographic policy as of the specified time')
            [CompletionResult]::new('--trust-root', '--trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('--password-file', '--password-file', [CompletionResultType]::ParameterName, 'Seed the password cache with the specified password')
            [CompletionResult]::new('--overwrite', '--overwrite', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('-v', '-v', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('--verbose', '--verbose', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--batch', '--batch', [CompletionResultType]::ParameterName, 'Prevents any kind of prompting')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;key;userid' {
            [CompletionResult]::new('--cli-version', '--cli-version', [CompletionResultType]::ParameterName, 'Select a CLI version')
            [CompletionResult]::new('--home', '--home', [CompletionResultType]::ParameterName, 'Set the home directory')
            [CompletionResult]::new('--key-store', '--key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', '--cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--keyring', '--keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--known-notation', '--known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', '--time', [CompletionResultType]::ParameterName, 'Set the reference time as an ISO 8601 formatted timestamp')
            [CompletionResult]::new('--policy-as-of', '--policy-as-of', [CompletionResultType]::ParameterName, 'Select the cryptographic policy as of the specified time')
            [CompletionResult]::new('--trust-root', '--trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('--password-file', '--password-file', [CompletionResultType]::ParameterName, 'Seed the password cache with the specified password')
            [CompletionResult]::new('--overwrite', '--overwrite', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('-v', '-v', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('--verbose', '--verbose', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--batch', '--batch', [CompletionResultType]::ParameterName, 'Prevents any kind of prompting')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('add', 'add', [CompletionResultType]::ParameterValue, 'Add a user ID')
            [CompletionResult]::new('revoke', 'revoke', [CompletionResultType]::ParameterValue, 'Revoke a user ID')
            break
        }
        'sq;key;userid;add' {
            [CompletionResult]::new('--cert', '--cert', [CompletionResultType]::ParameterName, 'Add the user ID to the key with the specified fingerprint or key ID')
            [CompletionResult]::new('--cert-userid', '--cert-userid', [CompletionResultType]::ParameterName, 'Add the user ID to the key with the specified user ID')
            [CompletionResult]::new('--cert-email', '--cert-email', [CompletionResultType]::ParameterName, 'Add the user ID to the key where a user ID includes the specified email address')
            [CompletionResult]::new('--cert-file', '--cert-file', [CompletionResultType]::ParameterName, 'Add the user ID to the key read from PATH')
            [CompletionResult]::new('--name', '--name', [CompletionResultType]::ParameterName, 'Add a name as user ID to the key')
            [CompletionResult]::new('--email', '--email', [CompletionResultType]::ParameterName, 'Add an email address as user ID to the key')
            [CompletionResult]::new('--userid', '--userid', [CompletionResultType]::ParameterName, 'Add a user ID to the key')
            [CompletionResult]::new('--output', '--output', [CompletionResultType]::ParameterName, 'Write to the specified FILE')
            [CompletionResult]::new('--cli-version', '--cli-version', [CompletionResultType]::ParameterName, 'Select a CLI version')
            [CompletionResult]::new('--home', '--home', [CompletionResultType]::ParameterName, 'Set the home directory')
            [CompletionResult]::new('--key-store', '--key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', '--cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--keyring', '--keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--known-notation', '--known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', '--time', [CompletionResultType]::ParameterName, 'Set the reference time as an ISO 8601 formatted timestamp')
            [CompletionResult]::new('--policy-as-of', '--policy-as-of', [CompletionResultType]::ParameterName, 'Select the cryptographic policy as of the specified time')
            [CompletionResult]::new('--trust-root', '--trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('--password-file', '--password-file', [CompletionResultType]::ParameterName, 'Seed the password cache with the specified password')
            [CompletionResult]::new('--allow-non-canonical-userids', '--allow-non-canonical-userids', [CompletionResultType]::ParameterName, 'Don''t reject user IDs that are not in canonical form')
            [CompletionResult]::new('--overwrite', '--overwrite', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('-v', '-v', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('--verbose', '--verbose', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--batch', '--batch', [CompletionResultType]::ParameterName, 'Prevents any kind of prompting')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;key;userid;revoke' {
            [CompletionResult]::new('--cert', '--cert', [CompletionResultType]::ParameterName, 'Revoke the user ID from the key with the specified fingerprint or key ID')
            [CompletionResult]::new('--cert-userid', '--cert-userid', [CompletionResultType]::ParameterName, 'Revoke the user ID from the key with the specified user ID')
            [CompletionResult]::new('--cert-email', '--cert-email', [CompletionResultType]::ParameterName, 'Revoke the user ID from the key where a user ID includes the specified email address')
            [CompletionResult]::new('--cert-file', '--cert-file', [CompletionResultType]::ParameterName, 'Revoke the user ID from the key read from PATH')
            [CompletionResult]::new('--revoker', '--revoker', [CompletionResultType]::ParameterName, 'Use key with the specified fingerprint or key ID to create the revocation certificate')
            [CompletionResult]::new('--revoker-userid', '--revoker-userid', [CompletionResultType]::ParameterName, 'Use key with the specified user ID to create the revocation certificate')
            [CompletionResult]::new('--revoker-email', '--revoker-email', [CompletionResultType]::ParameterName, 'Use key where a user ID includes the specified email address to create the revocation certificate')
            [CompletionResult]::new('--revoker-file', '--revoker-file', [CompletionResultType]::ParameterName, 'Read key from PATH to create the revocation certificate')
            [CompletionResult]::new('--userid', '--userid', [CompletionResultType]::ParameterName, 'Use the specified self-signed user ID')
            [CompletionResult]::new('--add-userid', '--add-userid', [CompletionResultType]::ParameterName, 'Use the specified user ID')
            [CompletionResult]::new('--userid-by-email', '--userid-by-email', [CompletionResultType]::ParameterName, 'Use the self-signed user ID with the specified email address')
            [CompletionResult]::new('--email', '--email', [CompletionResultType]::ParameterName, 'Use a user ID consisting of just the email address, if the email address occurs in a self-signed user ID')
            [CompletionResult]::new('--add-email', '--add-email', [CompletionResultType]::ParameterName, 'Use a user ID with the specified email address')
            [CompletionResult]::new('--reason', '--reason', [CompletionResultType]::ParameterName, 'The reason for the revocation')
            [CompletionResult]::new('--message', '--message', [CompletionResultType]::ParameterName, 'A short, explanatory text')
            [CompletionResult]::new('--signature-notation', '--signature-notation', [CompletionResultType]::ParameterName, 'Add a notation to the signature')
            [CompletionResult]::new('--output', '--output', [CompletionResultType]::ParameterName, 'Write to the specified FILE')
            [CompletionResult]::new('--cli-version', '--cli-version', [CompletionResultType]::ParameterName, 'Select a CLI version')
            [CompletionResult]::new('--home', '--home', [CompletionResultType]::ParameterName, 'Set the home directory')
            [CompletionResult]::new('--key-store', '--key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', '--cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--keyring', '--keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--known-notation', '--known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', '--time', [CompletionResultType]::ParameterName, 'Set the reference time as an ISO 8601 formatted timestamp')
            [CompletionResult]::new('--policy-as-of', '--policy-as-of', [CompletionResultType]::ParameterName, 'Select the cryptographic policy as of the specified time')
            [CompletionResult]::new('--trust-root', '--trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('--password-file', '--password-file', [CompletionResultType]::ParameterName, 'Seed the password cache with the specified password')
            [CompletionResult]::new('--allow-non-canonical-userids', '--allow-non-canonical-userids', [CompletionResultType]::ParameterName, 'Don''t reject new user IDs that are not in canonical form')
            [CompletionResult]::new('--overwrite', '--overwrite', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('-v', '-v', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('--verbose', '--verbose', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--batch', '--batch', [CompletionResultType]::ParameterName, 'Prevents any kind of prompting')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;key;subkey' {
            [CompletionResult]::new('--cli-version', '--cli-version', [CompletionResultType]::ParameterName, 'Select a CLI version')
            [CompletionResult]::new('--home', '--home', [CompletionResultType]::ParameterName, 'Set the home directory')
            [CompletionResult]::new('--key-store', '--key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', '--cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--keyring', '--keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--known-notation', '--known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', '--time', [CompletionResultType]::ParameterName, 'Set the reference time as an ISO 8601 formatted timestamp')
            [CompletionResult]::new('--policy-as-of', '--policy-as-of', [CompletionResultType]::ParameterName, 'Select the cryptographic policy as of the specified time')
            [CompletionResult]::new('--trust-root', '--trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('--password-file', '--password-file', [CompletionResultType]::ParameterName, 'Seed the password cache with the specified password')
            [CompletionResult]::new('--overwrite', '--overwrite', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('-v', '-v', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('--verbose', '--verbose', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--batch', '--batch', [CompletionResultType]::ParameterName, 'Prevents any kind of prompting')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('add', 'add', [CompletionResultType]::ParameterValue, 'Add a new subkey to a certificate')
            [CompletionResult]::new('export', 'export', [CompletionResultType]::ParameterValue, 'Export secret key material from the secret key store')
            [CompletionResult]::new('delete', 'delete', [CompletionResultType]::ParameterValue, 'Delete a certificate''s secret key material')
            [CompletionResult]::new('password', 'password', [CompletionResultType]::ParameterValue, 'Change the password protecting secret key material')
            [CompletionResult]::new('expire', 'expire', [CompletionResultType]::ParameterValue, 'Change a subkey''s expiration time')
            [CompletionResult]::new('revoke', 'revoke', [CompletionResultType]::ParameterValue, 'Revoke a subkey')
            [CompletionResult]::new('bind', 'bind', [CompletionResultType]::ParameterValue, 'Bind keys from one certificate to another')
            break
        }
        'sq;key;subkey;add' {
            [CompletionResult]::new('--cert', '--cert', [CompletionResultType]::ParameterName, 'Add a subkey to the key with the specified fingerprint or key ID')
            [CompletionResult]::new('--cert-userid', '--cert-userid', [CompletionResultType]::ParameterName, 'Add a subkey to the key with the specified user ID')
            [CompletionResult]::new('--cert-email', '--cert-email', [CompletionResultType]::ParameterName, 'Add a subkey to the key where a user ID includes the specified email address')
            [CompletionResult]::new('--cert-file', '--cert-file', [CompletionResultType]::ParameterName, 'Add a subkey to the key read from PATH')
            [CompletionResult]::new('--cipher-suite', '--cipher-suite', [CompletionResultType]::ParameterName, 'Select the cryptographic algorithms for the subkey')
            [CompletionResult]::new('--expiration', '--expiration', [CompletionResultType]::ParameterName, 'Sets the expiration time')
            [CompletionResult]::new('--can-encrypt', '--can-encrypt', [CompletionResultType]::ParameterName, 'Add an encryption-capable subkey [default: universal]')
            [CompletionResult]::new('--new-password-file', '--new-password-file', [CompletionResultType]::ParameterName, 'File containing password to encrypt the secret key material')
            [CompletionResult]::new('--output', '--output', [CompletionResultType]::ParameterName, 'Write to the specified FILE')
            [CompletionResult]::new('--cli-version', '--cli-version', [CompletionResultType]::ParameterName, 'Select a CLI version')
            [CompletionResult]::new('--home', '--home', [CompletionResultType]::ParameterName, 'Set the home directory')
            [CompletionResult]::new('--key-store', '--key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', '--cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--keyring', '--keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--known-notation', '--known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', '--time', [CompletionResultType]::ParameterName, 'Set the reference time as an ISO 8601 formatted timestamp')
            [CompletionResult]::new('--policy-as-of', '--policy-as-of', [CompletionResultType]::ParameterName, 'Select the cryptographic policy as of the specified time')
            [CompletionResult]::new('--trust-root', '--trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('--password-file', '--password-file', [CompletionResultType]::ParameterName, 'Seed the password cache with the specified password')
            [CompletionResult]::new('--can-sign', '--can-sign', [CompletionResultType]::ParameterName, 'Add a signing-capable subkey')
            [CompletionResult]::new('--can-authenticate', '--can-authenticate', [CompletionResultType]::ParameterName, 'Add an authentication-capable subkey')
            [CompletionResult]::new('--without-password', '--without-password', [CompletionResultType]::ParameterName, 'Don''t protect the subkey''s secret key material with a password')
            [CompletionResult]::new('--overwrite', '--overwrite', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('-v', '-v', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('--verbose', '--verbose', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--batch', '--batch', [CompletionResultType]::ParameterName, 'Prevents any kind of prompting')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;key;subkey;export' {
            [CompletionResult]::new('--cert', '--cert', [CompletionResultType]::ParameterName, 'Use certificates with the specified fingerprint or key ID')
            [CompletionResult]::new('--cert-userid', '--cert-userid', [CompletionResultType]::ParameterName, 'Use certificates with the specified user ID')
            [CompletionResult]::new('--cert-email', '--cert-email', [CompletionResultType]::ParameterName, 'Use certificates where a user ID includes the specified email address')
            [CompletionResult]::new('--key', '--key', [CompletionResultType]::ParameterName, 'Export the secret key material for the specified primary key or subkey')
            [CompletionResult]::new('--output', '--output', [CompletionResultType]::ParameterName, 'Write to FILE or stdout if omitted')
            [CompletionResult]::new('--cli-version', '--cli-version', [CompletionResultType]::ParameterName, 'Select a CLI version')
            [CompletionResult]::new('--home', '--home', [CompletionResultType]::ParameterName, 'Set the home directory')
            [CompletionResult]::new('--key-store', '--key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', '--cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--keyring', '--keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--known-notation', '--known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', '--time', [CompletionResultType]::ParameterName, 'Set the reference time as an ISO 8601 formatted timestamp')
            [CompletionResult]::new('--policy-as-of', '--policy-as-of', [CompletionResultType]::ParameterName, 'Select the cryptographic policy as of the specified time')
            [CompletionResult]::new('--trust-root', '--trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('--password-file', '--password-file', [CompletionResultType]::ParameterName, 'Seed the password cache with the specified password')
            [CompletionResult]::new('--overwrite', '--overwrite', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('-v', '-v', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('--verbose', '--verbose', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--batch', '--batch', [CompletionResultType]::ParameterName, 'Prevents any kind of prompting')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;key;subkey;delete' {
            [CompletionResult]::new('--cert', '--cert', [CompletionResultType]::ParameterName, 'Delete secret key material from the key with the specified fingerprint or key ID')
            [CompletionResult]::new('--cert-userid', '--cert-userid', [CompletionResultType]::ParameterName, 'Delete secret key material from the key with the specified user ID')
            [CompletionResult]::new('--cert-email', '--cert-email', [CompletionResultType]::ParameterName, 'Delete secret key material from the key where a user ID includes the specified email address')
            [CompletionResult]::new('--cert-file', '--cert-file', [CompletionResultType]::ParameterName, 'Delete the secret key material from the key read from PATH')
            [CompletionResult]::new('--key', '--key', [CompletionResultType]::ParameterName, 'Delete the specified key''s secret key material')
            [CompletionResult]::new('--output', '--output', [CompletionResultType]::ParameterName, 'Write the stripped certificate to the specified file')
            [CompletionResult]::new('--cli-version', '--cli-version', [CompletionResultType]::ParameterName, 'Select a CLI version')
            [CompletionResult]::new('--home', '--home', [CompletionResultType]::ParameterName, 'Set the home directory')
            [CompletionResult]::new('--key-store', '--key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', '--cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--keyring', '--keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--known-notation', '--known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', '--time', [CompletionResultType]::ParameterName, 'Set the reference time as an ISO 8601 formatted timestamp')
            [CompletionResult]::new('--policy-as-of', '--policy-as-of', [CompletionResultType]::ParameterName, 'Select the cryptographic policy as of the specified time')
            [CompletionResult]::new('--trust-root', '--trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('--password-file', '--password-file', [CompletionResultType]::ParameterName, 'Seed the password cache with the specified password')
            [CompletionResult]::new('--overwrite', '--overwrite', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('-v', '-v', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('--verbose', '--verbose', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--batch', '--batch', [CompletionResultType]::ParameterName, 'Prevents any kind of prompting')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;key;subkey;password' {
            [CompletionResult]::new('--cert', '--cert', [CompletionResultType]::ParameterName, 'Change the password for the secret key material of the specified (sub)keys from the key with the specified fingerprint or key ID')
            [CompletionResult]::new('--cert-userid', '--cert-userid', [CompletionResultType]::ParameterName, 'Change the password for the secret key material of the specified (sub)keys from the key with the specified user ID')
            [CompletionResult]::new('--cert-email', '--cert-email', [CompletionResultType]::ParameterName, 'Change the password for the secret key material of the specified (sub)keys from the key where a user ID includes the specified email address')
            [CompletionResult]::new('--cert-file', '--cert-file', [CompletionResultType]::ParameterName, 'Change the password for the secret key material of the specified (sub)keys from the key read from PATH')
            [CompletionResult]::new('--key', '--key', [CompletionResultType]::ParameterName, 'Change the password protecting the specified key''s secret key material')
            [CompletionResult]::new('--new-password-file', '--new-password-file', [CompletionResultType]::ParameterName, 'File containing password to encrypt the secret key material')
            [CompletionResult]::new('--output', '--output', [CompletionResultType]::ParameterName, 'Write to FILE or stdout if omitted')
            [CompletionResult]::new('--cli-version', '--cli-version', [CompletionResultType]::ParameterName, 'Select a CLI version')
            [CompletionResult]::new('--home', '--home', [CompletionResultType]::ParameterName, 'Set the home directory')
            [CompletionResult]::new('--key-store', '--key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', '--cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--keyring', '--keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--known-notation', '--known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', '--time', [CompletionResultType]::ParameterName, 'Set the reference time as an ISO 8601 formatted timestamp')
            [CompletionResult]::new('--policy-as-of', '--policy-as-of', [CompletionResultType]::ParameterName, 'Select the cryptographic policy as of the specified time')
            [CompletionResult]::new('--trust-root', '--trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('--password-file', '--password-file', [CompletionResultType]::ParameterName, 'Seed the password cache with the specified password')
            [CompletionResult]::new('--clear-password', '--clear-password', [CompletionResultType]::ParameterName, 'Clear the password protecting the secret key material')
            [CompletionResult]::new('--overwrite', '--overwrite', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('-v', '-v', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('--verbose', '--verbose', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--batch', '--batch', [CompletionResultType]::ParameterName, 'Prevents any kind of prompting')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;key;subkey;expire' {
            [CompletionResult]::new('--cert', '--cert', [CompletionResultType]::ParameterName, 'Change the expiration of the specified (sub)keys on the key with the specified fingerprint or key ID')
            [CompletionResult]::new('--cert-userid', '--cert-userid', [CompletionResultType]::ParameterName, 'Change the expiration of the specified (sub)keys on the key with the specified user ID')
            [CompletionResult]::new('--cert-email', '--cert-email', [CompletionResultType]::ParameterName, 'Change the expiration of the specified (sub)keys on the key where a user ID includes the specified email address')
            [CompletionResult]::new('--cert-file', '--cert-file', [CompletionResultType]::ParameterName, 'Change the expiration of the specified (sub)keys on the key read from PATH')
            [CompletionResult]::new('--key', '--key', [CompletionResultType]::ParameterName, 'Use the key with the specified fingerprint or key ID')
            [CompletionResult]::new('--output', '--output', [CompletionResultType]::ParameterName, 'Write to the specified FILE')
            [CompletionResult]::new('--expiration', '--expiration', [CompletionResultType]::ParameterName, 'Sets the expiration time')
            [CompletionResult]::new('--cli-version', '--cli-version', [CompletionResultType]::ParameterName, 'Select a CLI version')
            [CompletionResult]::new('--home', '--home', [CompletionResultType]::ParameterName, 'Set the home directory')
            [CompletionResult]::new('--key-store', '--key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', '--cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--keyring', '--keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--known-notation', '--known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', '--time', [CompletionResultType]::ParameterName, 'Set the reference time as an ISO 8601 formatted timestamp')
            [CompletionResult]::new('--policy-as-of', '--policy-as-of', [CompletionResultType]::ParameterName, 'Select the cryptographic policy as of the specified time')
            [CompletionResult]::new('--trust-root', '--trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('--password-file', '--password-file', [CompletionResultType]::ParameterName, 'Seed the password cache with the specified password')
            [CompletionResult]::new('--overwrite', '--overwrite', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('-v', '-v', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('--verbose', '--verbose', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--batch', '--batch', [CompletionResultType]::ParameterName, 'Prevents any kind of prompting')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;key;subkey;revoke' {
            [CompletionResult]::new('--cert', '--cert', [CompletionResultType]::ParameterName, 'Revoke the specified subkeys on the key with the specified fingerprint or key ID')
            [CompletionResult]::new('--cert-userid', '--cert-userid', [CompletionResultType]::ParameterName, 'Revoke the specified subkeys on the key with the specified user ID')
            [CompletionResult]::new('--cert-email', '--cert-email', [CompletionResultType]::ParameterName, 'Revoke the specified subkeys on the key where a user ID includes the specified email address')
            [CompletionResult]::new('--cert-file', '--cert-file', [CompletionResultType]::ParameterName, 'Revoke the specified subkeys on the key read from PATH')
            [CompletionResult]::new('--revoker', '--revoker', [CompletionResultType]::ParameterName, 'Use key with the specified fingerprint or key ID to create the revocation certificate')
            [CompletionResult]::new('--revoker-userid', '--revoker-userid', [CompletionResultType]::ParameterName, 'Use key with the specified user ID to create the revocation certificate')
            [CompletionResult]::new('--revoker-email', '--revoker-email', [CompletionResultType]::ParameterName, 'Use key where a user ID includes the specified email address to create the revocation certificate')
            [CompletionResult]::new('--revoker-file', '--revoker-file', [CompletionResultType]::ParameterName, 'Read key from PATH to create the revocation certificate')
            [CompletionResult]::new('--key', '--key', [CompletionResultType]::ParameterName, 'Revoke the specified subkey')
            [CompletionResult]::new('--reason', '--reason', [CompletionResultType]::ParameterName, 'The reason for the revocation')
            [CompletionResult]::new('--message', '--message', [CompletionResultType]::ParameterName, 'A short, explanatory text')
            [CompletionResult]::new('--signature-notation', '--signature-notation', [CompletionResultType]::ParameterName, 'Add a notation to the signature')
            [CompletionResult]::new('--output', '--output', [CompletionResultType]::ParameterName, 'Write to the specified FILE')
            [CompletionResult]::new('--cli-version', '--cli-version', [CompletionResultType]::ParameterName, 'Select a CLI version')
            [CompletionResult]::new('--home', '--home', [CompletionResultType]::ParameterName, 'Set the home directory')
            [CompletionResult]::new('--key-store', '--key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', '--cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--keyring', '--keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--known-notation', '--known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', '--time', [CompletionResultType]::ParameterName, 'Set the reference time as an ISO 8601 formatted timestamp')
            [CompletionResult]::new('--policy-as-of', '--policy-as-of', [CompletionResultType]::ParameterName, 'Select the cryptographic policy as of the specified time')
            [CompletionResult]::new('--trust-root', '--trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('--password-file', '--password-file', [CompletionResultType]::ParameterName, 'Seed the password cache with the specified password')
            [CompletionResult]::new('--overwrite', '--overwrite', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('-v', '-v', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('--verbose', '--verbose', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--batch', '--batch', [CompletionResultType]::ParameterName, 'Prevents any kind of prompting')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;key;subkey;bind' {
            [CompletionResult]::new('--cert', '--cert', [CompletionResultType]::ParameterName, 'Add the specified subkeys on the key with the specified fingerprint or key ID')
            [CompletionResult]::new('--cert-userid', '--cert-userid', [CompletionResultType]::ParameterName, 'Add the specified subkeys on the key with the specified user ID')
            [CompletionResult]::new('--cert-email', '--cert-email', [CompletionResultType]::ParameterName, 'Add the specified subkeys on the key where a user ID includes the specified email address')
            [CompletionResult]::new('--cert-file', '--cert-file', [CompletionResultType]::ParameterName, 'Add the specified subkeys to the key read from PATH')
            [CompletionResult]::new('--key', '--key', [CompletionResultType]::ParameterName, 'Add the key or subkey KEY to the certificate')
            [CompletionResult]::new('--creation-time', '--creation-time', [CompletionResultType]::ParameterName, 'Make bound subkeys have the specified creation time')
            [CompletionResult]::new('--expiration', '--expiration', [CompletionResultType]::ParameterName, 'Sets the expiration time')
            [CompletionResult]::new('--can-encrypt', '--can-encrypt', [CompletionResultType]::ParameterName, 'Set the encryption-capable flag')
            [CompletionResult]::new('--output', '--output', [CompletionResultType]::ParameterName, 'Write to the specified FILE')
            [CompletionResult]::new('--cli-version', '--cli-version', [CompletionResultType]::ParameterName, 'Select a CLI version')
            [CompletionResult]::new('--home', '--home', [CompletionResultType]::ParameterName, 'Set the home directory')
            [CompletionResult]::new('--key-store', '--key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', '--cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--keyring', '--keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--known-notation', '--known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', '--time', [CompletionResultType]::ParameterName, 'Set the reference time as an ISO 8601 formatted timestamp')
            [CompletionResult]::new('--policy-as-of', '--policy-as-of', [CompletionResultType]::ParameterName, 'Select the cryptographic policy as of the specified time')
            [CompletionResult]::new('--trust-root', '--trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('--password-file', '--password-file', [CompletionResultType]::ParameterName, 'Seed the password cache with the specified password')
            [CompletionResult]::new('--allow-broken-crypto', '--allow-broken-crypto', [CompletionResultType]::ParameterName, 'Allow adopting keys from certificates using broken cryptography')
            [CompletionResult]::new('--can-sign', '--can-sign', [CompletionResultType]::ParameterName, 'Set the signing-capable flag')
            [CompletionResult]::new('--cannot-sign', '--cannot-sign', [CompletionResultType]::ParameterName, 'Don''t set the signing-capable flag')
            [CompletionResult]::new('--can-authenticate', '--can-authenticate', [CompletionResultType]::ParameterName, 'Set the authentication-capable flag')
            [CompletionResult]::new('--cannot-authenticate', '--cannot-authenticate', [CompletionResultType]::ParameterName, 'Don''t set the authentication-capable flag')
            [CompletionResult]::new('--cannot-encrypt', '--cannot-encrypt', [CompletionResultType]::ParameterName, 'Don''t set the encryption-capable flag')
            [CompletionResult]::new('--overwrite', '--overwrite', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('-v', '-v', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('--verbose', '--verbose', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--batch', '--batch', [CompletionResultType]::ParameterName, 'Prevents any kind of prompting')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;key;approvals' {
            [CompletionResult]::new('--cli-version', '--cli-version', [CompletionResultType]::ParameterName, 'Select a CLI version')
            [CompletionResult]::new('--home', '--home', [CompletionResultType]::ParameterName, 'Set the home directory')
            [CompletionResult]::new('--key-store', '--key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', '--cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--keyring', '--keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--known-notation', '--known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', '--time', [CompletionResultType]::ParameterName, 'Set the reference time as an ISO 8601 formatted timestamp')
            [CompletionResult]::new('--policy-as-of', '--policy-as-of', [CompletionResultType]::ParameterName, 'Select the cryptographic policy as of the specified time')
            [CompletionResult]::new('--trust-root', '--trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('--password-file', '--password-file', [CompletionResultType]::ParameterName, 'Seed the password cache with the specified password')
            [CompletionResult]::new('--overwrite', '--overwrite', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('-v', '-v', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('--verbose', '--verbose', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--batch', '--batch', [CompletionResultType]::ParameterName, 'Prevents any kind of prompting')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'Lists third-party certifications and their approval status')
            [CompletionResult]::new('update', 'update', [CompletionResultType]::ParameterValue, 'Approves of third-party certifications allowing for their distribution')
            break
        }
        'sq;key;approvals;list' {
            [CompletionResult]::new('--cert', '--cert', [CompletionResultType]::ParameterName, 'List the approvals on the certificate with the specified fingerprint or key ID')
            [CompletionResult]::new('--cert-userid', '--cert-userid', [CompletionResultType]::ParameterName, 'List the approvals on the certificate with the specified user ID')
            [CompletionResult]::new('--cert-email', '--cert-email', [CompletionResultType]::ParameterName, 'List the approvals on the certificate where a user ID includes the specified email address')
            [CompletionResult]::new('--cert-file', '--cert-file', [CompletionResultType]::ParameterName, 'List the approvals on the certificate read from PATH')
            [CompletionResult]::new('--userid', '--userid', [CompletionResultType]::ParameterName, 'Use the specified self-signed user ID')
            [CompletionResult]::new('--email', '--email', [CompletionResultType]::ParameterName, 'Use the self-signed user ID with the specified email address')
            [CompletionResult]::new('--cli-version', '--cli-version', [CompletionResultType]::ParameterName, 'Select a CLI version')
            [CompletionResult]::new('--home', '--home', [CompletionResultType]::ParameterName, 'Set the home directory')
            [CompletionResult]::new('--key-store', '--key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', '--cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--keyring', '--keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--known-notation', '--known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', '--time', [CompletionResultType]::ParameterName, 'Set the reference time as an ISO 8601 formatted timestamp')
            [CompletionResult]::new('--policy-as-of', '--policy-as-of', [CompletionResultType]::ParameterName, 'Select the cryptographic policy as of the specified time')
            [CompletionResult]::new('--trust-root', '--trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('--password-file', '--password-file', [CompletionResultType]::ParameterName, 'Seed the password cache with the specified password')
            [CompletionResult]::new('--pending', '--pending', [CompletionResultType]::ParameterName, 'List unapproved certifications')
            [CompletionResult]::new('--overwrite', '--overwrite', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('-v', '-v', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('--verbose', '--verbose', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--batch', '--batch', [CompletionResultType]::ParameterName, 'Prevents any kind of prompting')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;key;approvals;update' {
            [CompletionResult]::new('--cert', '--cert', [CompletionResultType]::ParameterName, 'List the approvals on the certificate with the specified fingerprint or key ID')
            [CompletionResult]::new('--cert-userid', '--cert-userid', [CompletionResultType]::ParameterName, 'List the approvals on the certificate with the specified user ID')
            [CompletionResult]::new('--cert-email', '--cert-email', [CompletionResultType]::ParameterName, 'List the approvals on the certificate where a user ID includes the specified email address')
            [CompletionResult]::new('--cert-file', '--cert-file', [CompletionResultType]::ParameterName, 'List the approvals on the certificate read from PATH')
            [CompletionResult]::new('--userid', '--userid', [CompletionResultType]::ParameterName, 'Use the specified self-signed user ID')
            [CompletionResult]::new('--email', '--email', [CompletionResultType]::ParameterName, 'Use the self-signed user ID with the specified email address')
            [CompletionResult]::new('--remove-by', '--remove-by', [CompletionResultType]::ParameterName, 'Remove all prior approvals of certifications by this certifier')
            [CompletionResult]::new('--add-by', '--add-by', [CompletionResultType]::ParameterName, 'Approve of all certifications by this certifier')
            [CompletionResult]::new('--output', '--output', [CompletionResultType]::ParameterName, 'Write to the specified FILE')
            [CompletionResult]::new('--cli-version', '--cli-version', [CompletionResultType]::ParameterName, 'Select a CLI version')
            [CompletionResult]::new('--home', '--home', [CompletionResultType]::ParameterName, 'Set the home directory')
            [CompletionResult]::new('--key-store', '--key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', '--cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--keyring', '--keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--known-notation', '--known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', '--time', [CompletionResultType]::ParameterName, 'Set the reference time as an ISO 8601 formatted timestamp')
            [CompletionResult]::new('--policy-as-of', '--policy-as-of', [CompletionResultType]::ParameterName, 'Select the cryptographic policy as of the specified time')
            [CompletionResult]::new('--trust-root', '--trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('--password-file', '--password-file', [CompletionResultType]::ParameterName, 'Seed the password cache with the specified password')
            [CompletionResult]::new('--remove-all', '--remove-all', [CompletionResultType]::ParameterName, 'Remove all prior approvals')
            [CompletionResult]::new('--add-all', '--add-all', [CompletionResultType]::ParameterName, 'Approve of all pending certifications')
            [CompletionResult]::new('--add-authenticated', '--add-authenticated', [CompletionResultType]::ParameterName, 'Approve of all certifications by authenticated certifiers')
            [CompletionResult]::new('--overwrite', '--overwrite', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('-v', '-v', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('--verbose', '--verbose', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--batch', '--batch', [CompletionResultType]::ParameterName, 'Prevents any kind of prompting')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;pki' {
            [CompletionResult]::new('--cli-version', '--cli-version', [CompletionResultType]::ParameterName, 'Select a CLI version')
            [CompletionResult]::new('--home', '--home', [CompletionResultType]::ParameterName, 'Set the home directory')
            [CompletionResult]::new('--key-store', '--key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', '--cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--keyring', '--keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--known-notation', '--known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', '--time', [CompletionResultType]::ParameterName, 'Set the reference time as an ISO 8601 formatted timestamp')
            [CompletionResult]::new('--policy-as-of', '--policy-as-of', [CompletionResultType]::ParameterName, 'Select the cryptographic policy as of the specified time')
            [CompletionResult]::new('--trust-root', '--trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('--password-file', '--password-file', [CompletionResultType]::ParameterName, 'Seed the password cache with the specified password')
            [CompletionResult]::new('--overwrite', '--overwrite', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('-v', '-v', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('--verbose', '--verbose', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--batch', '--batch', [CompletionResultType]::ParameterName, 'Prevents any kind of prompting')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('authenticate', 'authenticate', [CompletionResultType]::ParameterValue, 'Authenticate a binding')
            [CompletionResult]::new('lookup', 'lookup', [CompletionResultType]::ParameterValue, 'Lookup the certificates associated with a User ID')
            [CompletionResult]::new('identify', 'identify', [CompletionResultType]::ParameterValue, 'Identify a certificate')
            [CompletionResult]::new('vouch', 'vouch', [CompletionResultType]::ParameterValue, 'Manage certifications')
            [CompletionResult]::new('link', 'link', [CompletionResultType]::ParameterValue, 'Manage authenticated certificate and User ID links')
            [CompletionResult]::new('path', 'path', [CompletionResultType]::ParameterValue, 'Verify the specified path')
            break
        }
        'sq;pki;authenticate' {
            [CompletionResult]::new('--cert', '--cert', [CompletionResultType]::ParameterName, 'Use certificates with the specified fingerprint or key ID')
            [CompletionResult]::new('--userid', '--userid', [CompletionResultType]::ParameterName, 'Authenticate the specified user ID')
            [CompletionResult]::new('--email', '--email', [CompletionResultType]::ParameterName, 'Authenticate the specified email address')
            [CompletionResult]::new('--amount', '--amount', [CompletionResultType]::ParameterName, 'The required amount of trust')
            [CompletionResult]::new('--cli-version', '--cli-version', [CompletionResultType]::ParameterName, 'Select a CLI version')
            [CompletionResult]::new('--home', '--home', [CompletionResultType]::ParameterName, 'Set the home directory')
            [CompletionResult]::new('--key-store', '--key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', '--cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--keyring', '--keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--known-notation', '--known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', '--time', [CompletionResultType]::ParameterName, 'Set the reference time as an ISO 8601 formatted timestamp')
            [CompletionResult]::new('--policy-as-of', '--policy-as-of', [CompletionResultType]::ParameterName, 'Select the cryptographic policy as of the specified time')
            [CompletionResult]::new('--trust-root', '--trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('--password-file', '--password-file', [CompletionResultType]::ParameterName, 'Seed the password cache with the specified password')
            [CompletionResult]::new('--show-paths', '--show-paths', [CompletionResultType]::ParameterName, 'Show why a binding is authenticated')
            [CompletionResult]::new('--gossip', '--gossip', [CompletionResultType]::ParameterName, 'Treats all certificates as unreliable trust roots')
            [CompletionResult]::new('--unusable', '--unusable', [CompletionResultType]::ParameterName, 'Show bindings that are unusable')
            [CompletionResult]::new('--certification-network', '--certification-network', [CompletionResultType]::ParameterName, 'Treats the network as a certification network')
            [CompletionResult]::new('--overwrite', '--overwrite', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('-v', '-v', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('--verbose', '--verbose', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--batch', '--batch', [CompletionResultType]::ParameterName, 'Prevents any kind of prompting')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;pki;lookup' {
            [CompletionResult]::new('--userid', '--userid', [CompletionResultType]::ParameterName, 'Find certificates that can be authenticated for the specified user ID')
            [CompletionResult]::new('--email', '--email', [CompletionResultType]::ParameterName, 'Find certificates that can be authenticated for the specified email address')
            [CompletionResult]::new('--amount', '--amount', [CompletionResultType]::ParameterName, 'The required amount of trust')
            [CompletionResult]::new('--cli-version', '--cli-version', [CompletionResultType]::ParameterName, 'Select a CLI version')
            [CompletionResult]::new('--home', '--home', [CompletionResultType]::ParameterName, 'Set the home directory')
            [CompletionResult]::new('--key-store', '--key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', '--cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--keyring', '--keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--known-notation', '--known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', '--time', [CompletionResultType]::ParameterName, 'Set the reference time as an ISO 8601 formatted timestamp')
            [CompletionResult]::new('--policy-as-of', '--policy-as-of', [CompletionResultType]::ParameterName, 'Select the cryptographic policy as of the specified time')
            [CompletionResult]::new('--trust-root', '--trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('--password-file', '--password-file', [CompletionResultType]::ParameterName, 'Seed the password cache with the specified password')
            [CompletionResult]::new('--show-paths', '--show-paths', [CompletionResultType]::ParameterName, 'Show why a binding is authenticated')
            [CompletionResult]::new('--gossip', '--gossip', [CompletionResultType]::ParameterName, 'Treats all certificates as unreliable trust roots')
            [CompletionResult]::new('--unusable', '--unusable', [CompletionResultType]::ParameterName, 'Show bindings that are unusable')
            [CompletionResult]::new('--certification-network', '--certification-network', [CompletionResultType]::ParameterName, 'Treats the network as a certification network')
            [CompletionResult]::new('--overwrite', '--overwrite', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('-v', '-v', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('--verbose', '--verbose', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--batch', '--batch', [CompletionResultType]::ParameterName, 'Prevents any kind of prompting')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;pki;identify' {
            [CompletionResult]::new('--cert', '--cert', [CompletionResultType]::ParameterName, 'Use certificates with the specified fingerprint or key ID')
            [CompletionResult]::new('--amount', '--amount', [CompletionResultType]::ParameterName, 'The required amount of trust')
            [CompletionResult]::new('--cli-version', '--cli-version', [CompletionResultType]::ParameterName, 'Select a CLI version')
            [CompletionResult]::new('--home', '--home', [CompletionResultType]::ParameterName, 'Set the home directory')
            [CompletionResult]::new('--key-store', '--key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', '--cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--keyring', '--keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--known-notation', '--known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', '--time', [CompletionResultType]::ParameterName, 'Set the reference time as an ISO 8601 formatted timestamp')
            [CompletionResult]::new('--policy-as-of', '--policy-as-of', [CompletionResultType]::ParameterName, 'Select the cryptographic policy as of the specified time')
            [CompletionResult]::new('--trust-root', '--trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('--password-file', '--password-file', [CompletionResultType]::ParameterName, 'Seed the password cache with the specified password')
            [CompletionResult]::new('--show-paths', '--show-paths', [CompletionResultType]::ParameterName, 'Show why a binding is authenticated')
            [CompletionResult]::new('--gossip', '--gossip', [CompletionResultType]::ParameterName, 'Treats all certificates as unreliable trust roots')
            [CompletionResult]::new('--unusable', '--unusable', [CompletionResultType]::ParameterName, 'Show bindings that are unusable')
            [CompletionResult]::new('--certification-network', '--certification-network', [CompletionResultType]::ParameterName, 'Treats the network as a certification network')
            [CompletionResult]::new('--overwrite', '--overwrite', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('-v', '-v', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('--verbose', '--verbose', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--batch', '--batch', [CompletionResultType]::ParameterName, 'Prevents any kind of prompting')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;pki;vouch' {
            [CompletionResult]::new('--cli-version', '--cli-version', [CompletionResultType]::ParameterName, 'Select a CLI version')
            [CompletionResult]::new('--home', '--home', [CompletionResultType]::ParameterName, 'Set the home directory')
            [CompletionResult]::new('--key-store', '--key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', '--cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--keyring', '--keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--known-notation', '--known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', '--time', [CompletionResultType]::ParameterName, 'Set the reference time as an ISO 8601 formatted timestamp')
            [CompletionResult]::new('--policy-as-of', '--policy-as-of', [CompletionResultType]::ParameterName, 'Select the cryptographic policy as of the specified time')
            [CompletionResult]::new('--trust-root', '--trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('--password-file', '--password-file', [CompletionResultType]::ParameterName, 'Seed the password cache with the specified password')
            [CompletionResult]::new('--overwrite', '--overwrite', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('-v', '-v', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('--verbose', '--verbose', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--batch', '--batch', [CompletionResultType]::ParameterName, 'Prevents any kind of prompting')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('add', 'add', [CompletionResultType]::ParameterValue, 'Certify a User ID for a Certificate')
            [CompletionResult]::new('authorize', 'authorize', [CompletionResultType]::ParameterValue, 'Mark a certificate as a trusted introducer')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List certifications')
            [CompletionResult]::new('replay', 'replay', [CompletionResultType]::ParameterValue, 'Replays vouches')
            break
        }
        'sq;pki;vouch;add' {
            [CompletionResult]::new('--certifier', '--certifier', [CompletionResultType]::ParameterName, 'Create the certification using the key with the specified fingerprint or key ID')
            [CompletionResult]::new('--certifier-userid', '--certifier-userid', [CompletionResultType]::ParameterName, 'Create the certification using the key with the specified user ID')
            [CompletionResult]::new('--certifier-email', '--certifier-email', [CompletionResultType]::ParameterName, 'Create the certification using the key where a user ID includes the specified email address')
            [CompletionResult]::new('--certifier-file', '--certifier-file', [CompletionResultType]::ParameterName, 'Create the certification using the key read from PATH')
            [CompletionResult]::new('--cert', '--cert', [CompletionResultType]::ParameterName, 'Use certificates with the specified fingerprint or key ID')
            [CompletionResult]::new('--cert-file', '--cert-file', [CompletionResultType]::ParameterName, 'Read certificates from PATH')
            [CompletionResult]::new('--userid', '--userid', [CompletionResultType]::ParameterName, 'Use the specified self-signed user ID')
            [CompletionResult]::new('--add-userid', '--add-userid', [CompletionResultType]::ParameterName, 'Use the specified user ID')
            [CompletionResult]::new('--userid-by-email', '--userid-by-email', [CompletionResultType]::ParameterName, 'Use the self-signed user ID with the specified email address')
            [CompletionResult]::new('--email', '--email', [CompletionResultType]::ParameterName, 'Use a user ID consisting of just the email address, if the email address occurs in a self-signed user ID')
            [CompletionResult]::new('--add-email', '--add-email', [CompletionResultType]::ParameterName, 'Use a user ID with the specified email address')
            [CompletionResult]::new('--amount', '--amount', [CompletionResultType]::ParameterName, 'Set the amount of trust')
            [CompletionResult]::new('--expiration', '--expiration', [CompletionResultType]::ParameterName, 'Sets the expiration time')
            [CompletionResult]::new('--signature-notation', '--signature-notation', [CompletionResultType]::ParameterName, 'Add a notation to the signature')
            [CompletionResult]::new('--output', '--output', [CompletionResultType]::ParameterName, 'Write to FILE or stdout if omitted')
            [CompletionResult]::new('--cli-version', '--cli-version', [CompletionResultType]::ParameterName, 'Select a CLI version')
            [CompletionResult]::new('--home', '--home', [CompletionResultType]::ParameterName, 'Set the home directory')
            [CompletionResult]::new('--key-store', '--key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', '--cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--keyring', '--keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--known-notation', '--known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', '--time', [CompletionResultType]::ParameterName, 'Set the reference time as an ISO 8601 formatted timestamp')
            [CompletionResult]::new('--policy-as-of', '--policy-as-of', [CompletionResultType]::ParameterName, 'Select the cryptographic policy as of the specified time')
            [CompletionResult]::new('--trust-root', '--trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('--password-file', '--password-file', [CompletionResultType]::ParameterName, 'Seed the password cache with the specified password')
            [CompletionResult]::new('--certifier-self', '--certifier-self', [CompletionResultType]::ParameterName, 'Create the certification using your default certification key')
            [CompletionResult]::new('--all', '--all', [CompletionResultType]::ParameterName, 'Use all self-signed user IDs')
            [CompletionResult]::new('--allow-non-canonical-userids', '--allow-non-canonical-userids', [CompletionResultType]::ParameterName, 'Don''t reject new user IDs that are not in canonical form')
            [CompletionResult]::new('--local', '--local', [CompletionResultType]::ParameterName, 'Make the certification a local certification')
            [CompletionResult]::new('--non-revocable', '--non-revocable', [CompletionResultType]::ParameterName, 'Mark the certification as being non-revocable')
            [CompletionResult]::new('--overwrite', '--overwrite', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('-v', '-v', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('--verbose', '--verbose', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--batch', '--batch', [CompletionResultType]::ParameterName, 'Prevents any kind of prompting')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;pki;vouch;authorize' {
            [CompletionResult]::new('--certifier', '--certifier', [CompletionResultType]::ParameterName, 'Create the certification using the key with the specified fingerprint or key ID')
            [CompletionResult]::new('--certifier-userid', '--certifier-userid', [CompletionResultType]::ParameterName, 'Create the certification using the key with the specified user ID')
            [CompletionResult]::new('--certifier-email', '--certifier-email', [CompletionResultType]::ParameterName, 'Create the certification using the key where a user ID includes the specified email address')
            [CompletionResult]::new('--certifier-file', '--certifier-file', [CompletionResultType]::ParameterName, 'Create the certification using the key read from PATH')
            [CompletionResult]::new('--cert', '--cert', [CompletionResultType]::ParameterName, 'Use certificates with the specified fingerprint or key ID')
            [CompletionResult]::new('--cert-file', '--cert-file', [CompletionResultType]::ParameterName, 'Read certificates from PATH')
            [CompletionResult]::new('--userid', '--userid', [CompletionResultType]::ParameterName, 'Use the specified self-signed user ID')
            [CompletionResult]::new('--add-userid', '--add-userid', [CompletionResultType]::ParameterName, 'Use the specified user ID')
            [CompletionResult]::new('--userid-by-email', '--userid-by-email', [CompletionResultType]::ParameterName, 'Use the self-signed user ID with the specified email address')
            [CompletionResult]::new('--email', '--email', [CompletionResultType]::ParameterName, 'Use a user ID consisting of just the email address, if the email address occurs in a self-signed user ID')
            [CompletionResult]::new('--add-email', '--add-email', [CompletionResultType]::ParameterName, 'Use a user ID with the specified email address')
            [CompletionResult]::new('--amount', '--amount', [CompletionResultType]::ParameterName, 'Set the amount of trust')
            [CompletionResult]::new('--depth', '--depth', [CompletionResultType]::ParameterName, 'Set the trust depth')
            [CompletionResult]::new('--domain', '--domain', [CompletionResultType]::ParameterName, 'Add a domain constraint to the introducer')
            [CompletionResult]::new('--regex', '--regex', [CompletionResultType]::ParameterName, 'Add a regular expression to constrain the introducer')
            [CompletionResult]::new('--expiration', '--expiration', [CompletionResultType]::ParameterName, 'Sets the expiration time')
            [CompletionResult]::new('--signature-notation', '--signature-notation', [CompletionResultType]::ParameterName, 'Add a notation to the signature')
            [CompletionResult]::new('--output', '--output', [CompletionResultType]::ParameterName, 'Write to FILE or stdout if omitted')
            [CompletionResult]::new('--cli-version', '--cli-version', [CompletionResultType]::ParameterName, 'Select a CLI version')
            [CompletionResult]::new('--home', '--home', [CompletionResultType]::ParameterName, 'Set the home directory')
            [CompletionResult]::new('--key-store', '--key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', '--cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--keyring', '--keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--known-notation', '--known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', '--time', [CompletionResultType]::ParameterName, 'Set the reference time as an ISO 8601 formatted timestamp')
            [CompletionResult]::new('--policy-as-of', '--policy-as-of', [CompletionResultType]::ParameterName, 'Select the cryptographic policy as of the specified time')
            [CompletionResult]::new('--trust-root', '--trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('--password-file', '--password-file', [CompletionResultType]::ParameterName, 'Seed the password cache with the specified password')
            [CompletionResult]::new('--certifier-self', '--certifier-self', [CompletionResultType]::ParameterName, 'Create the certification using your default certification key')
            [CompletionResult]::new('--all', '--all', [CompletionResultType]::ParameterName, 'Use all self-signed user IDs')
            [CompletionResult]::new('--allow-non-canonical-userids', '--allow-non-canonical-userids', [CompletionResultType]::ParameterName, 'Don''t reject new user IDs that are not in canonical form')
            [CompletionResult]::new('--unconstrained', '--unconstrained', [CompletionResultType]::ParameterName, 'Don''t constrain the introducer')
            [CompletionResult]::new('--local', '--local', [CompletionResultType]::ParameterName, 'Make the certification a local certification')
            [CompletionResult]::new('--non-revocable', '--non-revocable', [CompletionResultType]::ParameterName, 'Mark the certification as being non-revocable')
            [CompletionResult]::new('--overwrite', '--overwrite', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('-v', '-v', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('--verbose', '--verbose', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--batch', '--batch', [CompletionResultType]::ParameterName, 'Prevents any kind of prompting')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;pki;vouch;list' {
            [CompletionResult]::new('--certifier', '--certifier', [CompletionResultType]::ParameterName, 'Use certificates with the specified fingerprint or key ID')
            [CompletionResult]::new('--certifier-special', '--certifier-special', [CompletionResultType]::ParameterName, 'Use certificates identified by the special name')
            [CompletionResult]::new('--certifier-userid', '--certifier-userid', [CompletionResultType]::ParameterName, 'Use certificates with the specified user ID')
            [CompletionResult]::new('--certifier-email', '--certifier-email', [CompletionResultType]::ParameterName, 'Use certificates where a user ID includes the specified email address')
            [CompletionResult]::new('--certifier-file', '--certifier-file', [CompletionResultType]::ParameterName, 'Read certificates from PATH')
            [CompletionResult]::new('--cert', '--cert', [CompletionResultType]::ParameterName, 'Use certificates with the specified fingerprint or key ID')
            [CompletionResult]::new('--cert-userid', '--cert-userid', [CompletionResultType]::ParameterName, 'Use certificates with the specified user ID')
            [CompletionResult]::new('--cert-email', '--cert-email', [CompletionResultType]::ParameterName, 'Use certificates where a user ID includes the specified email address')
            [CompletionResult]::new('--cert-file', '--cert-file', [CompletionResultType]::ParameterName, 'Read certificates from PATH')
            [CompletionResult]::new('--cli-version', '--cli-version', [CompletionResultType]::ParameterName, 'Select a CLI version')
            [CompletionResult]::new('--home', '--home', [CompletionResultType]::ParameterName, 'Set the home directory')
            [CompletionResult]::new('--key-store', '--key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', '--cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--keyring', '--keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--known-notation', '--known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', '--time', [CompletionResultType]::ParameterName, 'Set the reference time as an ISO 8601 formatted timestamp')
            [CompletionResult]::new('--policy-as-of', '--policy-as-of', [CompletionResultType]::ParameterName, 'Select the cryptographic policy as of the specified time')
            [CompletionResult]::new('--trust-root', '--trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('--password-file', '--password-file', [CompletionResultType]::ParameterName, 'Seed the password cache with the specified password')
            [CompletionResult]::new('--certifier-self', '--certifier-self', [CompletionResultType]::ParameterName, 'Create the certification using your default certification key')
            [CompletionResult]::new('--overwrite', '--overwrite', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('-v', '-v', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('--verbose', '--verbose', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--batch', '--batch', [CompletionResultType]::ParameterName, 'Prevents any kind of prompting')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;pki;vouch;replay' {
            [CompletionResult]::new('--source', '--source', [CompletionResultType]::ParameterName, 'Use certificates with the specified fingerprint or key ID')
            [CompletionResult]::new('--source-userid', '--source-userid', [CompletionResultType]::ParameterName, 'Use certificates with the specified user ID')
            [CompletionResult]::new('--source-email', '--source-email', [CompletionResultType]::ParameterName, 'Use certificates where a user ID includes the specified email address')
            [CompletionResult]::new('--source-file', '--source-file', [CompletionResultType]::ParameterName, 'Read certificates from PATH')
            [CompletionResult]::new('--target', '--target', [CompletionResultType]::ParameterName, 'Use certificates with the specified fingerprint or key ID')
            [CompletionResult]::new('--target-userid', '--target-userid', [CompletionResultType]::ParameterName, 'Use certificates with the specified user ID')
            [CompletionResult]::new('--target-email', '--target-email', [CompletionResultType]::ParameterName, 'Use certificates where a user ID includes the specified email address')
            [CompletionResult]::new('--target-file', '--target-file', [CompletionResultType]::ParameterName, 'Read certificates from PATH')
            [CompletionResult]::new('--output', '--output', [CompletionResultType]::ParameterName, 'Write to FILE or stdout if omitted')
            [CompletionResult]::new('--cli-version', '--cli-version', [CompletionResultType]::ParameterName, 'Select a CLI version')
            [CompletionResult]::new('--home', '--home', [CompletionResultType]::ParameterName, 'Set the home directory')
            [CompletionResult]::new('--key-store', '--key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', '--cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--keyring', '--keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--known-notation', '--known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', '--time', [CompletionResultType]::ParameterName, 'Set the reference time as an ISO 8601 formatted timestamp')
            [CompletionResult]::new('--policy-as-of', '--policy-as-of', [CompletionResultType]::ParameterName, 'Select the cryptographic policy as of the specified time')
            [CompletionResult]::new('--trust-root', '--trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('--password-file', '--password-file', [CompletionResultType]::ParameterName, 'Seed the password cache with the specified password')
            [CompletionResult]::new('--allow-dissimilar-userids', '--allow-dissimilar-userids', [CompletionResultType]::ParameterName, 'Don''t check that the source and target share a self-signed user ID')
            [CompletionResult]::new('--overwrite', '--overwrite', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('-v', '-v', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('--verbose', '--verbose', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--batch', '--batch', [CompletionResultType]::ParameterName, 'Prevents any kind of prompting')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;pki;link' {
            [CompletionResult]::new('--cli-version', '--cli-version', [CompletionResultType]::ParameterName, 'Select a CLI version')
            [CompletionResult]::new('--home', '--home', [CompletionResultType]::ParameterName, 'Set the home directory')
            [CompletionResult]::new('--key-store', '--key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', '--cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--keyring', '--keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--known-notation', '--known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', '--time', [CompletionResultType]::ParameterName, 'Set the reference time as an ISO 8601 formatted timestamp')
            [CompletionResult]::new('--policy-as-of', '--policy-as-of', [CompletionResultType]::ParameterName, 'Select the cryptographic policy as of the specified time')
            [CompletionResult]::new('--trust-root', '--trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('--password-file', '--password-file', [CompletionResultType]::ParameterName, 'Seed the password cache with the specified password')
            [CompletionResult]::new('--overwrite', '--overwrite', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('-v', '-v', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('--verbose', '--verbose', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--batch', '--batch', [CompletionResultType]::ParameterName, 'Prevents any kind of prompting')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('add', 'add', [CompletionResultType]::ParameterValue, 'Link a certificate and a user ID')
            [CompletionResult]::new('authorize', 'authorize', [CompletionResultType]::ParameterValue, 'Make a certificate a trusted introducer')
            [CompletionResult]::new('retract', 'retract', [CompletionResultType]::ParameterValue, 'Retract links')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List links')
            break
        }
        'sq;pki;link;add' {
            [CompletionResult]::new('--cert', '--cert', [CompletionResultType]::ParameterName, 'Use certificates with the specified fingerprint or key ID')
            [CompletionResult]::new('--cert-special', '--cert-special', [CompletionResultType]::ParameterName, 'Use certificates identified by the special name')
            [CompletionResult]::new('--userid', '--userid', [CompletionResultType]::ParameterName, 'Use the specified self-signed user ID')
            [CompletionResult]::new('--add-userid', '--add-userid', [CompletionResultType]::ParameterName, 'Use the specified user ID')
            [CompletionResult]::new('--userid-by-email', '--userid-by-email', [CompletionResultType]::ParameterName, 'Use the self-signed user ID with the specified email address')
            [CompletionResult]::new('--email', '--email', [CompletionResultType]::ParameterName, 'Use a user ID consisting of just the email address, if the email address occurs in a self-signed user ID')
            [CompletionResult]::new('--add-email', '--add-email', [CompletionResultType]::ParameterName, 'Use a user ID with the specified email address')
            [CompletionResult]::new('--amount', '--amount', [CompletionResultType]::ParameterName, 'Set the amount of trust')
            [CompletionResult]::new('--expiration', '--expiration', [CompletionResultType]::ParameterName, 'Sets the expiration time')
            [CompletionResult]::new('--signature-notation', '--signature-notation', [CompletionResultType]::ParameterName, 'Add a notation to the signature')
            [CompletionResult]::new('--cli-version', '--cli-version', [CompletionResultType]::ParameterName, 'Select a CLI version')
            [CompletionResult]::new('--home', '--home', [CompletionResultType]::ParameterName, 'Set the home directory')
            [CompletionResult]::new('--key-store', '--key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', '--cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--keyring', '--keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--known-notation', '--known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', '--time', [CompletionResultType]::ParameterName, 'Set the reference time as an ISO 8601 formatted timestamp')
            [CompletionResult]::new('--policy-as-of', '--policy-as-of', [CompletionResultType]::ParameterName, 'Select the cryptographic policy as of the specified time')
            [CompletionResult]::new('--trust-root', '--trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('--password-file', '--password-file', [CompletionResultType]::ParameterName, 'Seed the password cache with the specified password')
            [CompletionResult]::new('--all', '--all', [CompletionResultType]::ParameterName, 'Use all self-signed user IDs')
            [CompletionResult]::new('--allow-non-canonical-userids', '--allow-non-canonical-userids', [CompletionResultType]::ParameterName, 'Don''t reject new user IDs that are not in canonical form')
            [CompletionResult]::new('--temporary', '--temporary', [CompletionResultType]::ParameterName, 'Temporarily accepts the binding')
            [CompletionResult]::new('--recreate', '--recreate', [CompletionResultType]::ParameterName, 'Recreate signature even if the parameters did not change')
            [CompletionResult]::new('--overwrite', '--overwrite', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('-v', '-v', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('--verbose', '--verbose', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--batch', '--batch', [CompletionResultType]::ParameterName, 'Prevents any kind of prompting')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;pki;link;authorize' {
            [CompletionResult]::new('--cert', '--cert', [CompletionResultType]::ParameterName, 'Use certificates with the specified fingerprint or key ID')
            [CompletionResult]::new('--cert-special', '--cert-special', [CompletionResultType]::ParameterName, 'Use certificates identified by the special name')
            [CompletionResult]::new('--userid', '--userid', [CompletionResultType]::ParameterName, 'Use the specified self-signed user ID')
            [CompletionResult]::new('--add-userid', '--add-userid', [CompletionResultType]::ParameterName, 'Use the specified user ID')
            [CompletionResult]::new('--userid-by-email', '--userid-by-email', [CompletionResultType]::ParameterName, 'Use the self-signed user ID with the specified email address')
            [CompletionResult]::new('--email', '--email', [CompletionResultType]::ParameterName, 'Use a user ID consisting of just the email address, if the email address occurs in a self-signed user ID')
            [CompletionResult]::new('--add-email', '--add-email', [CompletionResultType]::ParameterName, 'Use a user ID with the specified email address')
            [CompletionResult]::new('--amount', '--amount', [CompletionResultType]::ParameterName, 'Set the amount of trust')
            [CompletionResult]::new('--depth', '--depth', [CompletionResultType]::ParameterName, 'Set the trust depth')
            [CompletionResult]::new('--domain', '--domain', [CompletionResultType]::ParameterName, 'Add a domain constraint to the introducer')
            [CompletionResult]::new('--regex', '--regex', [CompletionResultType]::ParameterName, 'Add a regular expression to constrain the introducer')
            [CompletionResult]::new('--expiration', '--expiration', [CompletionResultType]::ParameterName, 'Sets the expiration time')
            [CompletionResult]::new('--signature-notation', '--signature-notation', [CompletionResultType]::ParameterName, 'Add a notation to the signature')
            [CompletionResult]::new('--cli-version', '--cli-version', [CompletionResultType]::ParameterName, 'Select a CLI version')
            [CompletionResult]::new('--home', '--home', [CompletionResultType]::ParameterName, 'Set the home directory')
            [CompletionResult]::new('--key-store', '--key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', '--cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--keyring', '--keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--known-notation', '--known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', '--time', [CompletionResultType]::ParameterName, 'Set the reference time as an ISO 8601 formatted timestamp')
            [CompletionResult]::new('--policy-as-of', '--policy-as-of', [CompletionResultType]::ParameterName, 'Select the cryptographic policy as of the specified time')
            [CompletionResult]::new('--trust-root', '--trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('--password-file', '--password-file', [CompletionResultType]::ParameterName, 'Seed the password cache with the specified password')
            [CompletionResult]::new('--all', '--all', [CompletionResultType]::ParameterName, 'Use all self-signed user IDs')
            [CompletionResult]::new('--allow-non-canonical-userids', '--allow-non-canonical-userids', [CompletionResultType]::ParameterName, 'Don''t reject new user IDs that are not in canonical form')
            [CompletionResult]::new('--unconstrained', '--unconstrained', [CompletionResultType]::ParameterName, 'Don''t constrain the introducer')
            [CompletionResult]::new('--recreate', '--recreate', [CompletionResultType]::ParameterName, 'Recreate the signature even if the parameters did not change')
            [CompletionResult]::new('--overwrite', '--overwrite', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('-v', '-v', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('--verbose', '--verbose', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--batch', '--batch', [CompletionResultType]::ParameterName, 'Prevents any kind of prompting')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;pki;link;retract' {
            [CompletionResult]::new('--signature-notation', '--signature-notation', [CompletionResultType]::ParameterName, 'Add a notation to the signature')
            [CompletionResult]::new('--cert', '--cert', [CompletionResultType]::ParameterName, 'Use certificates with the specified fingerprint or key ID')
            [CompletionResult]::new('--cert-special', '--cert-special', [CompletionResultType]::ParameterName, 'Use certificates identified by the special name')
            [CompletionResult]::new('--userid', '--userid', [CompletionResultType]::ParameterName, 'Use the specified user ID')
            [CompletionResult]::new('--userid-by-email', '--userid-by-email', [CompletionResultType]::ParameterName, 'Use the self-signed user ID with the specified email address')
            [CompletionResult]::new('--email', '--email', [CompletionResultType]::ParameterName, 'Use a user ID with the specified email address')
            [CompletionResult]::new('--cli-version', '--cli-version', [CompletionResultType]::ParameterName, 'Select a CLI version')
            [CompletionResult]::new('--home', '--home', [CompletionResultType]::ParameterName, 'Set the home directory')
            [CompletionResult]::new('--key-store', '--key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', '--cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--keyring', '--keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--known-notation', '--known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', '--time', [CompletionResultType]::ParameterName, 'Set the reference time as an ISO 8601 formatted timestamp')
            [CompletionResult]::new('--policy-as-of', '--policy-as-of', [CompletionResultType]::ParameterName, 'Select the cryptographic policy as of the specified time')
            [CompletionResult]::new('--trust-root', '--trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('--password-file', '--password-file', [CompletionResultType]::ParameterName, 'Seed the password cache with the specified password')
            [CompletionResult]::new('--recreate', '--recreate', [CompletionResultType]::ParameterName, 'Recreate signature even if the parameters did not change')
            [CompletionResult]::new('--all', '--all', [CompletionResultType]::ParameterName, 'Use all self-signed user IDs')
            [CompletionResult]::new('--overwrite', '--overwrite', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('-v', '-v', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('--verbose', '--verbose', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--batch', '--batch', [CompletionResultType]::ParameterName, 'Prevents any kind of prompting')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;pki;link;list' {
            [CompletionResult]::new('--cert', '--cert', [CompletionResultType]::ParameterName, 'Use certificates with the specified fingerprint or key ID')
            [CompletionResult]::new('--cert-userid', '--cert-userid', [CompletionResultType]::ParameterName, 'Use certificates with the specified user ID')
            [CompletionResult]::new('--cert-email', '--cert-email', [CompletionResultType]::ParameterName, 'Use certificates where a user ID includes the specified email address')
            [CompletionResult]::new('--cert-domain', '--cert-domain', [CompletionResultType]::ParameterName, 'Use certificates where a user ID includes an email address for the specified domain')
            [CompletionResult]::new('--cert-grep', '--cert-grep', [CompletionResultType]::ParameterName, 'Use certificates with a user ID that matches the pattern, case insensitively')
            [CompletionResult]::new('--cli-version', '--cli-version', [CompletionResultType]::ParameterName, 'Select a CLI version')
            [CompletionResult]::new('--home', '--home', [CompletionResultType]::ParameterName, 'Set the home directory')
            [CompletionResult]::new('--key-store', '--key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', '--cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--keyring', '--keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--known-notation', '--known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', '--time', [CompletionResultType]::ParameterName, 'Set the reference time as an ISO 8601 formatted timestamp')
            [CompletionResult]::new('--policy-as-of', '--policy-as-of', [CompletionResultType]::ParameterName, 'Select the cryptographic policy as of the specified time')
            [CompletionResult]::new('--trust-root', '--trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('--password-file', '--password-file', [CompletionResultType]::ParameterName, 'Seed the password cache with the specified password')
            [CompletionResult]::new('--ca', '--ca', [CompletionResultType]::ParameterName, 'Only lists bindings linked as CAs')
            [CompletionResult]::new('--overwrite', '--overwrite', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('-v', '-v', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('--verbose', '--verbose', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--batch', '--batch', [CompletionResultType]::ParameterName, 'Prevents any kind of prompting')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;pki;path' {
            [CompletionResult]::new('--userid', '--userid', [CompletionResultType]::ParameterName, 'Authenticate the specified user ID')
            [CompletionResult]::new('--userid-by-email', '--userid-by-email', [CompletionResultType]::ParameterName, 'Authenticate the self-signed user ID with the specified email address')
            [CompletionResult]::new('--email', '--email', [CompletionResultType]::ParameterName, 'Authenticate the specified email address')
            [CompletionResult]::new('--amount', '--amount', [CompletionResultType]::ParameterName, 'The required amount of trust')
            [CompletionResult]::new('--cli-version', '--cli-version', [CompletionResultType]::ParameterName, 'Select a CLI version')
            [CompletionResult]::new('--home', '--home', [CompletionResultType]::ParameterName, 'Set the home directory')
            [CompletionResult]::new('--key-store', '--key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', '--cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--keyring', '--keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--known-notation', '--known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', '--time', [CompletionResultType]::ParameterName, 'Set the reference time as an ISO 8601 formatted timestamp')
            [CompletionResult]::new('--policy-as-of', '--policy-as-of', [CompletionResultType]::ParameterName, 'Select the cryptographic policy as of the specified time')
            [CompletionResult]::new('--trust-root', '--trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('--password-file', '--password-file', [CompletionResultType]::ParameterName, 'Seed the password cache with the specified password')
            [CompletionResult]::new('--certification-network', '--certification-network', [CompletionResultType]::ParameterName, 'Treats the network as a certification network')
            [CompletionResult]::new('--overwrite', '--overwrite', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('-v', '-v', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('--verbose', '--verbose', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--batch', '--batch', [CompletionResultType]::ParameterName, 'Prevents any kind of prompting')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;network' {
            [CompletionResult]::new('--cli-version', '--cli-version', [CompletionResultType]::ParameterName, 'Select a CLI version')
            [CompletionResult]::new('--home', '--home', [CompletionResultType]::ParameterName, 'Set the home directory')
            [CompletionResult]::new('--key-store', '--key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', '--cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--keyring', '--keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--known-notation', '--known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', '--time', [CompletionResultType]::ParameterName, 'Set the reference time as an ISO 8601 formatted timestamp')
            [CompletionResult]::new('--policy-as-of', '--policy-as-of', [CompletionResultType]::ParameterName, 'Select the cryptographic policy as of the specified time')
            [CompletionResult]::new('--trust-root', '--trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('--password-file', '--password-file', [CompletionResultType]::ParameterName, 'Seed the password cache with the specified password')
            [CompletionResult]::new('--overwrite', '--overwrite', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('-v', '-v', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('--verbose', '--verbose', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--batch', '--batch', [CompletionResultType]::ParameterName, 'Prevents any kind of prompting')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('search', 'search', [CompletionResultType]::ParameterValue, 'Retrieve certificates using all supported network services')
            [CompletionResult]::new('keyserver', 'keyserver', [CompletionResultType]::ParameterValue, 'Retrieve and publishes certificates via key servers')
            [CompletionResult]::new('wkd', 'wkd', [CompletionResultType]::ParameterValue, 'Retrieve and publishes certificates via Web Key Directories')
            [CompletionResult]::new('dane', 'dane', [CompletionResultType]::ParameterValue, 'Retrieve and publishes certificates via DANE')
            break
        }
        'sq;network;search' {
            [CompletionResult]::new('--iterations', '--iterations', [CompletionResultType]::ParameterName, 'Iterate to find related updates and certs')
            [CompletionResult]::new('--server', '--server', [CompletionResultType]::ParameterName, 'Set a key server to use (can be given multiple times)')
            [CompletionResult]::new('--use-wkd', '--use-wkd', [CompletionResultType]::ParameterName, 'Use WKD to search for certs')
            [CompletionResult]::new('--use-dane', '--use-dane', [CompletionResultType]::ParameterName, 'Use DANE to search for certs')
            [CompletionResult]::new('--output', '--output', [CompletionResultType]::ParameterName, 'Write to FILE (or stdout when omitted) instead of importing into the certificate store')
            [CompletionResult]::new('--cli-version', '--cli-version', [CompletionResultType]::ParameterName, 'Select a CLI version')
            [CompletionResult]::new('--home', '--home', [CompletionResultType]::ParameterName, 'Set the home directory')
            [CompletionResult]::new('--key-store', '--key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', '--cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--keyring', '--keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--known-notation', '--known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', '--time', [CompletionResultType]::ParameterName, 'Set the reference time as an ISO 8601 formatted timestamp')
            [CompletionResult]::new('--policy-as-of', '--policy-as-of', [CompletionResultType]::ParameterName, 'Select the cryptographic policy as of the specified time')
            [CompletionResult]::new('--trust-root', '--trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('--password-file', '--password-file', [CompletionResultType]::ParameterName, 'Seed the password cache with the specified password')
            [CompletionResult]::new('--all', '--all', [CompletionResultType]::ParameterName, 'Fetch updates for all known certificates')
            [CompletionResult]::new('--overwrite', '--overwrite', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('-v', '-v', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('--verbose', '--verbose', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--batch', '--batch', [CompletionResultType]::ParameterName, 'Prevents any kind of prompting')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;network;keyserver' {
            [CompletionResult]::new('--server', '--server', [CompletionResultType]::ParameterName, 'Set a key server to use (can be given multiple times)')
            [CompletionResult]::new('--cli-version', '--cli-version', [CompletionResultType]::ParameterName, 'Select a CLI version')
            [CompletionResult]::new('--home', '--home', [CompletionResultType]::ParameterName, 'Set the home directory')
            [CompletionResult]::new('--key-store', '--key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', '--cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--keyring', '--keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--known-notation', '--known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', '--time', [CompletionResultType]::ParameterName, 'Set the reference time as an ISO 8601 formatted timestamp')
            [CompletionResult]::new('--policy-as-of', '--policy-as-of', [CompletionResultType]::ParameterName, 'Select the cryptographic policy as of the specified time')
            [CompletionResult]::new('--trust-root', '--trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('--password-file', '--password-file', [CompletionResultType]::ParameterName, 'Seed the password cache with the specified password')
            [CompletionResult]::new('--overwrite', '--overwrite', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('-v', '-v', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('--verbose', '--verbose', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--batch', '--batch', [CompletionResultType]::ParameterName, 'Prevents any kind of prompting')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('search', 'search', [CompletionResultType]::ParameterValue, 'Retrieve certificates from key servers')
            [CompletionResult]::new('publish', 'publish', [CompletionResultType]::ParameterValue, 'Publish certificates on key servers')
            break
        }
        'sq;network;keyserver;search' {
            [CompletionResult]::new('--output', '--output', [CompletionResultType]::ParameterName, 'Write to FILE (or stdout when omitted) instead of importing into the certificate store')
            [CompletionResult]::new('--server', '--server', [CompletionResultType]::ParameterName, 'Set a key server to use (can be given multiple times)')
            [CompletionResult]::new('--cli-version', '--cli-version', [CompletionResultType]::ParameterName, 'Select a CLI version')
            [CompletionResult]::new('--home', '--home', [CompletionResultType]::ParameterName, 'Set the home directory')
            [CompletionResult]::new('--key-store', '--key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', '--cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--keyring', '--keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--known-notation', '--known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', '--time', [CompletionResultType]::ParameterName, 'Set the reference time as an ISO 8601 formatted timestamp')
            [CompletionResult]::new('--policy-as-of', '--policy-as-of', [CompletionResultType]::ParameterName, 'Select the cryptographic policy as of the specified time')
            [CompletionResult]::new('--trust-root', '--trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('--password-file', '--password-file', [CompletionResultType]::ParameterName, 'Seed the password cache with the specified password')
            [CompletionResult]::new('--all', '--all', [CompletionResultType]::ParameterName, 'Fetch updates for all known certificates')
            [CompletionResult]::new('--overwrite', '--overwrite', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('-v', '-v', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('--verbose', '--verbose', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--batch', '--batch', [CompletionResultType]::ParameterName, 'Prevents any kind of prompting')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;network;keyserver;publish' {
            [CompletionResult]::new('--cert', '--cert', [CompletionResultType]::ParameterName, 'Use certificates with the specified fingerprint or key ID')
            [CompletionResult]::new('--cert-userid', '--cert-userid', [CompletionResultType]::ParameterName, 'Use certificates with the specified user ID')
            [CompletionResult]::new('--cert-email', '--cert-email', [CompletionResultType]::ParameterName, 'Use certificates where a user ID includes the specified email address')
            [CompletionResult]::new('--cert-domain', '--cert-domain', [CompletionResultType]::ParameterName, 'Use certificates where a user ID includes an email address for the specified domain')
            [CompletionResult]::new('--cert-file', '--cert-file', [CompletionResultType]::ParameterName, 'Read certificates from PATH')
            [CompletionResult]::new('--server', '--server', [CompletionResultType]::ParameterName, 'Set a key server to use (can be given multiple times)')
            [CompletionResult]::new('--cli-version', '--cli-version', [CompletionResultType]::ParameterName, 'Select a CLI version')
            [CompletionResult]::new('--home', '--home', [CompletionResultType]::ParameterName, 'Set the home directory')
            [CompletionResult]::new('--key-store', '--key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', '--cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--keyring', '--keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--known-notation', '--known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', '--time', [CompletionResultType]::ParameterName, 'Set the reference time as an ISO 8601 formatted timestamp')
            [CompletionResult]::new('--policy-as-of', '--policy-as-of', [CompletionResultType]::ParameterName, 'Select the cryptographic policy as of the specified time')
            [CompletionResult]::new('--trust-root', '--trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('--password-file', '--password-file', [CompletionResultType]::ParameterName, 'Seed the password cache with the specified password')
            [CompletionResult]::new('--overwrite', '--overwrite', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('-v', '-v', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('--verbose', '--verbose', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--batch', '--batch', [CompletionResultType]::ParameterName, 'Prevents any kind of prompting')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;network;wkd' {
            [CompletionResult]::new('--cli-version', '--cli-version', [CompletionResultType]::ParameterName, 'Select a CLI version')
            [CompletionResult]::new('--home', '--home', [CompletionResultType]::ParameterName, 'Set the home directory')
            [CompletionResult]::new('--key-store', '--key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', '--cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--keyring', '--keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--known-notation', '--known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', '--time', [CompletionResultType]::ParameterName, 'Set the reference time as an ISO 8601 formatted timestamp')
            [CompletionResult]::new('--policy-as-of', '--policy-as-of', [CompletionResultType]::ParameterName, 'Select the cryptographic policy as of the specified time')
            [CompletionResult]::new('--trust-root', '--trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('--password-file', '--password-file', [CompletionResultType]::ParameterName, 'Seed the password cache with the specified password')
            [CompletionResult]::new('--overwrite', '--overwrite', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('-v', '-v', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('--verbose', '--verbose', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--batch', '--batch', [CompletionResultType]::ParameterName, 'Prevents any kind of prompting')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('search', 'search', [CompletionResultType]::ParameterValue, 'Retrieve certificates from a Web Key Directory')
            [CompletionResult]::new('publish', 'publish', [CompletionResultType]::ParameterValue, 'Publish certificates in a Web Key Directory')
            break
        }
        'sq;network;wkd;search' {
            [CompletionResult]::new('--output', '--output', [CompletionResultType]::ParameterName, 'Write to FILE (or stdout when omitted) instead of importing into the certificate store')
            [CompletionResult]::new('--cli-version', '--cli-version', [CompletionResultType]::ParameterName, 'Select a CLI version')
            [CompletionResult]::new('--home', '--home', [CompletionResultType]::ParameterName, 'Set the home directory')
            [CompletionResult]::new('--key-store', '--key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', '--cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--keyring', '--keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--known-notation', '--known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', '--time', [CompletionResultType]::ParameterName, 'Set the reference time as an ISO 8601 formatted timestamp')
            [CompletionResult]::new('--policy-as-of', '--policy-as-of', [CompletionResultType]::ParameterName, 'Select the cryptographic policy as of the specified time')
            [CompletionResult]::new('--trust-root', '--trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('--password-file', '--password-file', [CompletionResultType]::ParameterName, 'Seed the password cache with the specified password')
            [CompletionResult]::new('--all', '--all', [CompletionResultType]::ParameterName, 'Fetch updates for all known certificates')
            [CompletionResult]::new('--overwrite', '--overwrite', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('-v', '-v', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('--verbose', '--verbose', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--batch', '--batch', [CompletionResultType]::ParameterName, 'Prevents any kind of prompting')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;network;wkd;publish' {
            [CompletionResult]::new('--cert', '--cert', [CompletionResultType]::ParameterName, 'Use certificates with the specified fingerprint or key ID')
            [CompletionResult]::new('--cert-userid', '--cert-userid', [CompletionResultType]::ParameterName, 'Use certificates with the specified user ID')
            [CompletionResult]::new('--cert-email', '--cert-email', [CompletionResultType]::ParameterName, 'Use certificates where a user ID includes the specified email address')
            [CompletionResult]::new('--cert-file', '--cert-file', [CompletionResultType]::ParameterName, 'Read certificates from PATH')
            [CompletionResult]::new('--method', '--method', [CompletionResultType]::ParameterName, 'Select kind of WKD hierarchy to be created')
            [CompletionResult]::new('--rsync-path', '--rsync-path', [CompletionResultType]::ParameterName, 'Path to the local rsync command to use, implies --rsync')
            [CompletionResult]::new('--domain', '--domain', [CompletionResultType]::ParameterName, 'Generate a WKD for a fully qualified domain name for email')
            [CompletionResult]::new('--cli-version', '--cli-version', [CompletionResultType]::ParameterName, 'Select a CLI version')
            [CompletionResult]::new('--home', '--home', [CompletionResultType]::ParameterName, 'Set the home directory')
            [CompletionResult]::new('--key-store', '--key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', '--cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--keyring', '--keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--known-notation', '--known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', '--time', [CompletionResultType]::ParameterName, 'Set the reference time as an ISO 8601 formatted timestamp')
            [CompletionResult]::new('--policy-as-of', '--policy-as-of', [CompletionResultType]::ParameterName, 'Select the cryptographic policy as of the specified time')
            [CompletionResult]::new('--trust-root', '--trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('--password-file', '--password-file', [CompletionResultType]::ParameterName, 'Seed the password cache with the specified password')
            [CompletionResult]::new('--all', '--all', [CompletionResultType]::ParameterName, 'Publish authenticated certs with a user ID matching domain')
            [CompletionResult]::new('--create', '--create', [CompletionResultType]::ParameterName, 'Create the WKD hierarchy if it does not exist yet')
            [CompletionResult]::new('--rsync', '--rsync', [CompletionResultType]::ParameterName, 'Use rsync(1) to access DEST')
            [CompletionResult]::new('--overwrite', '--overwrite', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('-v', '-v', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('--verbose', '--verbose', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--batch', '--batch', [CompletionResultType]::ParameterName, 'Prevents any kind of prompting')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;network;dane' {
            [CompletionResult]::new('--cli-version', '--cli-version', [CompletionResultType]::ParameterName, 'Select a CLI version')
            [CompletionResult]::new('--home', '--home', [CompletionResultType]::ParameterName, 'Set the home directory')
            [CompletionResult]::new('--key-store', '--key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', '--cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--keyring', '--keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--known-notation', '--known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', '--time', [CompletionResultType]::ParameterName, 'Set the reference time as an ISO 8601 formatted timestamp')
            [CompletionResult]::new('--policy-as-of', '--policy-as-of', [CompletionResultType]::ParameterName, 'Select the cryptographic policy as of the specified time')
            [CompletionResult]::new('--trust-root', '--trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('--password-file', '--password-file', [CompletionResultType]::ParameterName, 'Seed the password cache with the specified password')
            [CompletionResult]::new('--overwrite', '--overwrite', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('-v', '-v', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('--verbose', '--verbose', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--batch', '--batch', [CompletionResultType]::ParameterName, 'Prevents any kind of prompting')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('search', 'search', [CompletionResultType]::ParameterValue, 'Retrieve certificates using DANE')
            [CompletionResult]::new('generate', 'generate', [CompletionResultType]::ParameterValue, 'Generate DANE records for the given domain and certs')
            break
        }
        'sq;network;dane;search' {
            [CompletionResult]::new('--output', '--output', [CompletionResultType]::ParameterName, 'Write to FILE (or stdout when omitted) instead of importing into the certificate store')
            [CompletionResult]::new('--cli-version', '--cli-version', [CompletionResultType]::ParameterName, 'Select a CLI version')
            [CompletionResult]::new('--home', '--home', [CompletionResultType]::ParameterName, 'Set the home directory')
            [CompletionResult]::new('--key-store', '--key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', '--cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--keyring', '--keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--known-notation', '--known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', '--time', [CompletionResultType]::ParameterName, 'Set the reference time as an ISO 8601 formatted timestamp')
            [CompletionResult]::new('--policy-as-of', '--policy-as-of', [CompletionResultType]::ParameterName, 'Select the cryptographic policy as of the specified time')
            [CompletionResult]::new('--trust-root', '--trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('--password-file', '--password-file', [CompletionResultType]::ParameterName, 'Seed the password cache with the specified password')
            [CompletionResult]::new('--all', '--all', [CompletionResultType]::ParameterName, 'Fetch updates for all known certificates')
            [CompletionResult]::new('--overwrite', '--overwrite', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('-v', '-v', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('--verbose', '--verbose', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--batch', '--batch', [CompletionResultType]::ParameterName, 'Prevents any kind of prompting')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;network;dane;generate' {
            [CompletionResult]::new('--cert', '--cert', [CompletionResultType]::ParameterName, 'Use certificates with the specified fingerprint or key ID')
            [CompletionResult]::new('--cert-userid', '--cert-userid', [CompletionResultType]::ParameterName, 'Use certificates with the specified user ID')
            [CompletionResult]::new('--cert-email', '--cert-email', [CompletionResultType]::ParameterName, 'Use certificates where a user ID includes the specified email address')
            [CompletionResult]::new('--cert-file', '--cert-file', [CompletionResultType]::ParameterName, 'Read certificates from PATH')
            [CompletionResult]::new('--domain', '--domain', [CompletionResultType]::ParameterName, 'Generate DANE records for this domain name')
            [CompletionResult]::new('--ttl', '--ttl', [CompletionResultType]::ParameterName, 'Set the TTL (maximum cache duration) of the resource records')
            [CompletionResult]::new('--size-limit', '--size-limit', [CompletionResultType]::ParameterName, 'Try to shrink the certificates to this size')
            [CompletionResult]::new('--type', '--type', [CompletionResultType]::ParameterName, 'Change the emitted resource record type')
            [CompletionResult]::new('--cli-version', '--cli-version', [CompletionResultType]::ParameterName, 'Select a CLI version')
            [CompletionResult]::new('--home', '--home', [CompletionResultType]::ParameterName, 'Set the home directory')
            [CompletionResult]::new('--key-store', '--key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', '--cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--keyring', '--keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--known-notation', '--known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', '--time', [CompletionResultType]::ParameterName, 'Set the reference time as an ISO 8601 formatted timestamp')
            [CompletionResult]::new('--policy-as-of', '--policy-as-of', [CompletionResultType]::ParameterName, 'Select the cryptographic policy as of the specified time')
            [CompletionResult]::new('--trust-root', '--trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('--password-file', '--password-file', [CompletionResultType]::ParameterName, 'Seed the password cache with the specified password')
            [CompletionResult]::new('--all', '--all', [CompletionResultType]::ParameterName, 'Publish authenticated certs with a user ID matching domain')
            [CompletionResult]::new('--overwrite', '--overwrite', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('-v', '-v', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('--verbose', '--verbose', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--batch', '--batch', [CompletionResultType]::ParameterName, 'Prevents any kind of prompting')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;keyring' {
            [CompletionResult]::new('--cli-version', '--cli-version', [CompletionResultType]::ParameterName, 'Select a CLI version')
            [CompletionResult]::new('--home', '--home', [CompletionResultType]::ParameterName, 'Set the home directory')
            [CompletionResult]::new('--key-store', '--key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', '--cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--keyring', '--keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--known-notation', '--known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', '--time', [CompletionResultType]::ParameterName, 'Set the reference time as an ISO 8601 formatted timestamp')
            [CompletionResult]::new('--policy-as-of', '--policy-as-of', [CompletionResultType]::ParameterName, 'Select the cryptographic policy as of the specified time')
            [CompletionResult]::new('--trust-root', '--trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('--password-file', '--password-file', [CompletionResultType]::ParameterName, 'Seed the password cache with the specified password')
            [CompletionResult]::new('--overwrite', '--overwrite', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('-v', '-v', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('--verbose', '--verbose', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--batch', '--batch', [CompletionResultType]::ParameterName, 'Prevents any kind of prompting')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List keys in a keyring')
            [CompletionResult]::new('split', 'split', [CompletionResultType]::ParameterValue, 'Split a keyring into individual keys')
            [CompletionResult]::new('merge', 'merge', [CompletionResultType]::ParameterValue, 'Merge keys or keyrings into a single keyring')
            [CompletionResult]::new('filter', 'filter', [CompletionResultType]::ParameterValue, 'Join keys into a keyring applying a filter')
            break
        }
        'sq;keyring;list' {
            [CompletionResult]::new('--cli-version', '--cli-version', [CompletionResultType]::ParameterName, 'Select a CLI version')
            [CompletionResult]::new('--home', '--home', [CompletionResultType]::ParameterName, 'Set the home directory')
            [CompletionResult]::new('--key-store', '--key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', '--cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--keyring', '--keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--known-notation', '--known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', '--time', [CompletionResultType]::ParameterName, 'Set the reference time as an ISO 8601 formatted timestamp')
            [CompletionResult]::new('--policy-as-of', '--policy-as-of', [CompletionResultType]::ParameterName, 'Select the cryptographic policy as of the specified time')
            [CompletionResult]::new('--trust-root', '--trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('--password-file', '--password-file', [CompletionResultType]::ParameterName, 'Seed the password cache with the specified password')
            [CompletionResult]::new('--all-userids', '--all-userids', [CompletionResultType]::ParameterName, 'List all user IDs')
            [CompletionResult]::new('--overwrite', '--overwrite', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('-v', '-v', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('--verbose', '--verbose', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--batch', '--batch', [CompletionResultType]::ParameterName, 'Prevents any kind of prompting')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;keyring;split' {
            [CompletionResult]::new('--prefix', '--prefix', [CompletionResultType]::ParameterName, 'Write to files with PREFIX [defaults: `FILE-` if FILE is set, or `output-` if read from stdin]')
            [CompletionResult]::new('--cli-version', '--cli-version', [CompletionResultType]::ParameterName, 'Select a CLI version')
            [CompletionResult]::new('--home', '--home', [CompletionResultType]::ParameterName, 'Set the home directory')
            [CompletionResult]::new('--key-store', '--key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', '--cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--keyring', '--keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--known-notation', '--known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', '--time', [CompletionResultType]::ParameterName, 'Set the reference time as an ISO 8601 formatted timestamp')
            [CompletionResult]::new('--policy-as-of', '--policy-as-of', [CompletionResultType]::ParameterName, 'Select the cryptographic policy as of the specified time')
            [CompletionResult]::new('--trust-root', '--trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('--password-file', '--password-file', [CompletionResultType]::ParameterName, 'Seed the password cache with the specified password')
            [CompletionResult]::new('--overwrite', '--overwrite', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('-v', '-v', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('--verbose', '--verbose', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--batch', '--batch', [CompletionResultType]::ParameterName, 'Prevents any kind of prompting')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;keyring;merge' {
            [CompletionResult]::new('--output', '--output', [CompletionResultType]::ParameterName, 'Write to FILE or stdout if omitted')
            [CompletionResult]::new('--cli-version', '--cli-version', [CompletionResultType]::ParameterName, 'Select a CLI version')
            [CompletionResult]::new('--home', '--home', [CompletionResultType]::ParameterName, 'Set the home directory')
            [CompletionResult]::new('--key-store', '--key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', '--cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--keyring', '--keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--known-notation', '--known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', '--time', [CompletionResultType]::ParameterName, 'Set the reference time as an ISO 8601 formatted timestamp')
            [CompletionResult]::new('--policy-as-of', '--policy-as-of', [CompletionResultType]::ParameterName, 'Select the cryptographic policy as of the specified time')
            [CompletionResult]::new('--trust-root', '--trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('--password-file', '--password-file', [CompletionResultType]::ParameterName, 'Seed the password cache with the specified password')
            [CompletionResult]::new('--overwrite', '--overwrite', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('-v', '-v', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('--verbose', '--verbose', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--batch', '--batch', [CompletionResultType]::ParameterName, 'Prevents any kind of prompting')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;keyring;filter' {
            [CompletionResult]::new('--output', '--output', [CompletionResultType]::ParameterName, 'Write to FILE or stdout if omitted')
            [CompletionResult]::new('--userid', '--userid', [CompletionResultType]::ParameterName, 'Match on USERID')
            [CompletionResult]::new('--name', '--name', [CompletionResultType]::ParameterName, 'Match on NAME')
            [CompletionResult]::new('--email', '--email', [CompletionResultType]::ParameterName, 'Match on email ADDRESS')
            [CompletionResult]::new('--domain', '--domain', [CompletionResultType]::ParameterName, 'Match on email domain FQDN')
            [CompletionResult]::new('--cert', '--cert', [CompletionResultType]::ParameterName, 'Match on certificate fingerprints and key IDs')
            [CompletionResult]::new('--key', '--key', [CompletionResultType]::ParameterName, 'Match on (sub)key fingerprints and key IDs')
            [CompletionResult]::new('--cli-version', '--cli-version', [CompletionResultType]::ParameterName, 'Select a CLI version')
            [CompletionResult]::new('--home', '--home', [CompletionResultType]::ParameterName, 'Set the home directory')
            [CompletionResult]::new('--key-store', '--key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', '--cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--keyring', '--keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--known-notation', '--known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', '--time', [CompletionResultType]::ParameterName, 'Set the reference time as an ISO 8601 formatted timestamp')
            [CompletionResult]::new('--policy-as-of', '--policy-as-of', [CompletionResultType]::ParameterName, 'Select the cryptographic policy as of the specified time')
            [CompletionResult]::new('--trust-root', '--trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('--password-file', '--password-file', [CompletionResultType]::ParameterName, 'Seed the password cache with the specified password')
            [CompletionResult]::new('--experimental', '--experimental', [CompletionResultType]::ParameterName, 'Opt-in to using an experimental feature')
            [CompletionResult]::new('--prune-certs', '--prune-certs', [CompletionResultType]::ParameterName, 'Remove certificate components not matching the filter')
            [CompletionResult]::new('--to-cert', '--to-cert', [CompletionResultType]::ParameterName, 'Convert any keys in the input to certificates')
            [CompletionResult]::new('--overwrite', '--overwrite', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('-v', '-v', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('--verbose', '--verbose', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--batch', '--batch', [CompletionResultType]::ParameterName, 'Prevents any kind of prompting')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;packet' {
            [CompletionResult]::new('--cli-version', '--cli-version', [CompletionResultType]::ParameterName, 'Select a CLI version')
            [CompletionResult]::new('--home', '--home', [CompletionResultType]::ParameterName, 'Set the home directory')
            [CompletionResult]::new('--key-store', '--key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', '--cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--keyring', '--keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--known-notation', '--known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', '--time', [CompletionResultType]::ParameterName, 'Set the reference time as an ISO 8601 formatted timestamp')
            [CompletionResult]::new('--policy-as-of', '--policy-as-of', [CompletionResultType]::ParameterName, 'Select the cryptographic policy as of the specified time')
            [CompletionResult]::new('--trust-root', '--trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('--password-file', '--password-file', [CompletionResultType]::ParameterName, 'Seed the password cache with the specified password')
            [CompletionResult]::new('--overwrite', '--overwrite', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('-v', '-v', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('--verbose', '--verbose', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--batch', '--batch', [CompletionResultType]::ParameterName, 'Prevents any kind of prompting')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('armor', 'armor', [CompletionResultType]::ParameterValue, 'Convert binary to ASCII')
            [CompletionResult]::new('dearmor', 'dearmor', [CompletionResultType]::ParameterValue, 'Convert ASCII to binary')
            [CompletionResult]::new('dump', 'dump', [CompletionResultType]::ParameterValue, 'List packets')
            [CompletionResult]::new('decrypt', 'decrypt', [CompletionResultType]::ParameterValue, 'Unwrap an encryption container')
            [CompletionResult]::new('split', 'split', [CompletionResultType]::ParameterValue, 'Split a message into packets')
            [CompletionResult]::new('join', 'join', [CompletionResultType]::ParameterValue, 'Join packets split across files')
            break
        }
        'sq;packet;armor' {
            [CompletionResult]::new('--output', '--output', [CompletionResultType]::ParameterName, 'Write to FILE or stdout if omitted')
            [CompletionResult]::new('--label', '--label', [CompletionResultType]::ParameterName, 'Select the kind of armor header')
            [CompletionResult]::new('--cli-version', '--cli-version', [CompletionResultType]::ParameterName, 'Select a CLI version')
            [CompletionResult]::new('--home', '--home', [CompletionResultType]::ParameterName, 'Set the home directory')
            [CompletionResult]::new('--key-store', '--key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', '--cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--keyring', '--keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--known-notation', '--known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', '--time', [CompletionResultType]::ParameterName, 'Set the reference time as an ISO 8601 formatted timestamp')
            [CompletionResult]::new('--policy-as-of', '--policy-as-of', [CompletionResultType]::ParameterName, 'Select the cryptographic policy as of the specified time')
            [CompletionResult]::new('--trust-root', '--trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('--password-file', '--password-file', [CompletionResultType]::ParameterName, 'Seed the password cache with the specified password')
            [CompletionResult]::new('--overwrite', '--overwrite', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('-v', '-v', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('--verbose', '--verbose', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--batch', '--batch', [CompletionResultType]::ParameterName, 'Prevents any kind of prompting')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;packet;dearmor' {
            [CompletionResult]::new('--output', '--output', [CompletionResultType]::ParameterName, 'Write to FILE or stdout if omitted')
            [CompletionResult]::new('--cli-version', '--cli-version', [CompletionResultType]::ParameterName, 'Select a CLI version')
            [CompletionResult]::new('--home', '--home', [CompletionResultType]::ParameterName, 'Set the home directory')
            [CompletionResult]::new('--key-store', '--key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', '--cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--keyring', '--keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--known-notation', '--known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', '--time', [CompletionResultType]::ParameterName, 'Set the reference time as an ISO 8601 formatted timestamp')
            [CompletionResult]::new('--policy-as-of', '--policy-as-of', [CompletionResultType]::ParameterName, 'Select the cryptographic policy as of the specified time')
            [CompletionResult]::new('--trust-root', '--trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('--password-file', '--password-file', [CompletionResultType]::ParameterName, 'Seed the password cache with the specified password')
            [CompletionResult]::new('--overwrite', '--overwrite', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('-v', '-v', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('--verbose', '--verbose', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--batch', '--batch', [CompletionResultType]::ParameterName, 'Prevents any kind of prompting')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;packet;dump' {
            [CompletionResult]::new('--cert', '--cert', [CompletionResultType]::ParameterName, 'Dump the packets of the certificate with the specified fingerprint or key ID')
            [CompletionResult]::new('--cert-userid', '--cert-userid', [CompletionResultType]::ParameterName, 'Dump the packets of the certificate with the specified user ID')
            [CompletionResult]::new('--cert-email', '--cert-email', [CompletionResultType]::ParameterName, 'Dump the packets of the certificate where a user ID includes the specified email address')
            [CompletionResult]::new('--cert-file', '--cert-file', [CompletionResultType]::ParameterName, 'Dump the packets of the cert read from PATH')
            [CompletionResult]::new('--output', '--output', [CompletionResultType]::ParameterName, 'Write to FILE or stdout if omitted')
            [CompletionResult]::new('--session-key', '--session-key', [CompletionResultType]::ParameterName, 'Decrypt an encrypted message using SESSION-KEY')
            [CompletionResult]::new('--recipient-file', '--recipient-file', [CompletionResultType]::ParameterName, 'Decrypt the message using the key in KEY_FILE')
            [CompletionResult]::new('--cli-version', '--cli-version', [CompletionResultType]::ParameterName, 'Select a CLI version')
            [CompletionResult]::new('--home', '--home', [CompletionResultType]::ParameterName, 'Set the home directory')
            [CompletionResult]::new('--key-store', '--key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', '--cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--keyring', '--keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--known-notation', '--known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', '--time', [CompletionResultType]::ParameterName, 'Set the reference time as an ISO 8601 formatted timestamp')
            [CompletionResult]::new('--policy-as-of', '--policy-as-of', [CompletionResultType]::ParameterName, 'Select the cryptographic policy as of the specified time')
            [CompletionResult]::new('--trust-root', '--trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('--password-file', '--password-file', [CompletionResultType]::ParameterName, 'Seed the password cache with the specified password')
            [CompletionResult]::new('--mpis', '--mpis', [CompletionResultType]::ParameterName, 'Print cryptographic artifacts')
            [CompletionResult]::new('--hex', '--hex', [CompletionResultType]::ParameterName, 'Print a hexdump')
            [CompletionResult]::new('--overwrite', '--overwrite', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('-v', '-v', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('--verbose', '--verbose', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--batch', '--batch', [CompletionResultType]::ParameterName, 'Prevents any kind of prompting')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;packet;decrypt' {
            [CompletionResult]::new('--output', '--output', [CompletionResultType]::ParameterName, 'Write to FILE or stdout if omitted')
            [CompletionResult]::new('--recipient-file', '--recipient-file', [CompletionResultType]::ParameterName, 'Decrypt the message using the key in KEY_FILE')
            [CompletionResult]::new('--session-key', '--session-key', [CompletionResultType]::ParameterName, 'Decrypt an encrypted message using SESSION-KEY')
            [CompletionResult]::new('--cli-version', '--cli-version', [CompletionResultType]::ParameterName, 'Select a CLI version')
            [CompletionResult]::new('--home', '--home', [CompletionResultType]::ParameterName, 'Set the home directory')
            [CompletionResult]::new('--key-store', '--key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', '--cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--keyring', '--keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--known-notation', '--known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', '--time', [CompletionResultType]::ParameterName, 'Set the reference time as an ISO 8601 formatted timestamp')
            [CompletionResult]::new('--policy-as-of', '--policy-as-of', [CompletionResultType]::ParameterName, 'Select the cryptographic policy as of the specified time')
            [CompletionResult]::new('--trust-root', '--trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('--password-file', '--password-file', [CompletionResultType]::ParameterName, 'Seed the password cache with the specified password')
            [CompletionResult]::new('--binary', '--binary', [CompletionResultType]::ParameterName, 'Emit binary data')
            [CompletionResult]::new('--dump-session-key', '--dump-session-key', [CompletionResultType]::ParameterName, 'Print the session key to stderr')
            [CompletionResult]::new('--overwrite', '--overwrite', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('-v', '-v', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('--verbose', '--verbose', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--batch', '--batch', [CompletionResultType]::ParameterName, 'Prevents any kind of prompting')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;packet;split' {
            [CompletionResult]::new('--output', '--output', [CompletionResultType]::ParameterName, 'Write to FILE or stdout if omitted')
            [CompletionResult]::new('--output-prefix', '--output-prefix', [CompletionResultType]::ParameterName, 'Write packets to individual files starting with the given prefix.  The file names are formed by joining the prefix, the path of the packet in the source object (recall: packets can be nested), and a human-readable packet type with dashes (''-''). ')
            [CompletionResult]::new('--cli-version', '--cli-version', [CompletionResultType]::ParameterName, 'Select a CLI version')
            [CompletionResult]::new('--home', '--home', [CompletionResultType]::ParameterName, 'Set the home directory')
            [CompletionResult]::new('--key-store', '--key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', '--cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--keyring', '--keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--known-notation', '--known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', '--time', [CompletionResultType]::ParameterName, 'Set the reference time as an ISO 8601 formatted timestamp')
            [CompletionResult]::new('--policy-as-of', '--policy-as-of', [CompletionResultType]::ParameterName, 'Select the cryptographic policy as of the specified time')
            [CompletionResult]::new('--trust-root', '--trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('--password-file', '--password-file', [CompletionResultType]::ParameterName, 'Seed the password cache with the specified password')
            [CompletionResult]::new('--binary', '--binary', [CompletionResultType]::ParameterName, 'Emit binary data')
            [CompletionResult]::new('--overwrite', '--overwrite', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('-v', '-v', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('--verbose', '--verbose', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--batch', '--batch', [CompletionResultType]::ParameterName, 'Prevents any kind of prompting')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;packet;join' {
            [CompletionResult]::new('--output', '--output', [CompletionResultType]::ParameterName, 'Write to FILE or stdout if omitted')
            [CompletionResult]::new('--label', '--label', [CompletionResultType]::ParameterName, 'Select the kind of armor header')
            [CompletionResult]::new('--cli-version', '--cli-version', [CompletionResultType]::ParameterName, 'Select a CLI version')
            [CompletionResult]::new('--home', '--home', [CompletionResultType]::ParameterName, 'Set the home directory')
            [CompletionResult]::new('--key-store', '--key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', '--cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--keyring', '--keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--known-notation', '--known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', '--time', [CompletionResultType]::ParameterName, 'Set the reference time as an ISO 8601 formatted timestamp')
            [CompletionResult]::new('--policy-as-of', '--policy-as-of', [CompletionResultType]::ParameterName, 'Select the cryptographic policy as of the specified time')
            [CompletionResult]::new('--trust-root', '--trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('--password-file', '--password-file', [CompletionResultType]::ParameterName, 'Seed the password cache with the specified password')
            [CompletionResult]::new('--binary', '--binary', [CompletionResultType]::ParameterName, 'Emit binary data')
            [CompletionResult]::new('--overwrite', '--overwrite', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('-v', '-v', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('--verbose', '--verbose', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--batch', '--batch', [CompletionResultType]::ParameterName, 'Prevents any kind of prompting')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;config' {
            [CompletionResult]::new('--cli-version', '--cli-version', [CompletionResultType]::ParameterName, 'Select a CLI version')
            [CompletionResult]::new('--home', '--home', [CompletionResultType]::ParameterName, 'Set the home directory')
            [CompletionResult]::new('--key-store', '--key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', '--cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--keyring', '--keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--known-notation', '--known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', '--time', [CompletionResultType]::ParameterName, 'Set the reference time as an ISO 8601 formatted timestamp')
            [CompletionResult]::new('--policy-as-of', '--policy-as-of', [CompletionResultType]::ParameterName, 'Select the cryptographic policy as of the specified time')
            [CompletionResult]::new('--trust-root', '--trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('--password-file', '--password-file', [CompletionResultType]::ParameterName, 'Seed the password cache with the specified password')
            [CompletionResult]::new('--overwrite', '--overwrite', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('-v', '-v', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('--verbose', '--verbose', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--batch', '--batch', [CompletionResultType]::ParameterName, 'Prevents any kind of prompting')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('get', 'get', [CompletionResultType]::ParameterValue, 'Get configuration options')
            [CompletionResult]::new('inspect', 'inspect', [CompletionResultType]::ParameterValue, 'Inspect effective configuration details')
            [CompletionResult]::new('template', 'template', [CompletionResultType]::ParameterValue, 'Write a template configuration file')
            break
        }
        'sq;config;get' {
            [CompletionResult]::new('--cli-version', '--cli-version', [CompletionResultType]::ParameterName, 'Select a CLI version')
            [CompletionResult]::new('--home', '--home', [CompletionResultType]::ParameterName, 'Set the home directory')
            [CompletionResult]::new('--key-store', '--key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', '--cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--keyring', '--keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--known-notation', '--known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', '--time', [CompletionResultType]::ParameterName, 'Set the reference time as an ISO 8601 formatted timestamp')
            [CompletionResult]::new('--policy-as-of', '--policy-as-of', [CompletionResultType]::ParameterName, 'Select the cryptographic policy as of the specified time')
            [CompletionResult]::new('--trust-root', '--trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('--password-file', '--password-file', [CompletionResultType]::ParameterName, 'Seed the password cache with the specified password')
            [CompletionResult]::new('--overwrite', '--overwrite', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('-v', '-v', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('--verbose', '--verbose', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--batch', '--batch', [CompletionResultType]::ParameterName, 'Prevents any kind of prompting')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;config;inspect' {
            [CompletionResult]::new('--cli-version', '--cli-version', [CompletionResultType]::ParameterName, 'Select a CLI version')
            [CompletionResult]::new('--home', '--home', [CompletionResultType]::ParameterName, 'Set the home directory')
            [CompletionResult]::new('--key-store', '--key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', '--cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--keyring', '--keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--known-notation', '--known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', '--time', [CompletionResultType]::ParameterName, 'Set the reference time as an ISO 8601 formatted timestamp')
            [CompletionResult]::new('--policy-as-of', '--policy-as-of', [CompletionResultType]::ParameterName, 'Select the cryptographic policy as of the specified time')
            [CompletionResult]::new('--trust-root', '--trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('--password-file', '--password-file', [CompletionResultType]::ParameterName, 'Seed the password cache with the specified password')
            [CompletionResult]::new('--overwrite', '--overwrite', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('-v', '-v', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('--verbose', '--verbose', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--batch', '--batch', [CompletionResultType]::ParameterName, 'Prevents any kind of prompting')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('paths', 'paths', [CompletionResultType]::ParameterValue, 'Inspect relevant paths')
            [CompletionResult]::new('network', 'network', [CompletionResultType]::ParameterValue, 'Inspect the network configuration')
            [CompletionResult]::new('policy', 'policy', [CompletionResultType]::ParameterValue, 'Inspect the cryptographic policy')
            break
        }
        'sq;config;inspect;paths' {
            [CompletionResult]::new('--cli-version', '--cli-version', [CompletionResultType]::ParameterName, 'Select a CLI version')
            [CompletionResult]::new('--home', '--home', [CompletionResultType]::ParameterName, 'Set the home directory')
            [CompletionResult]::new('--key-store', '--key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', '--cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--keyring', '--keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--known-notation', '--known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', '--time', [CompletionResultType]::ParameterName, 'Set the reference time as an ISO 8601 formatted timestamp')
            [CompletionResult]::new('--policy-as-of', '--policy-as-of', [CompletionResultType]::ParameterName, 'Select the cryptographic policy as of the specified time')
            [CompletionResult]::new('--trust-root', '--trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('--password-file', '--password-file', [CompletionResultType]::ParameterName, 'Seed the password cache with the specified password')
            [CompletionResult]::new('--overwrite', '--overwrite', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('-v', '-v', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('--verbose', '--verbose', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--batch', '--batch', [CompletionResultType]::ParameterName, 'Prevents any kind of prompting')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;config;inspect;network' {
            [CompletionResult]::new('--cli-version', '--cli-version', [CompletionResultType]::ParameterName, 'Select a CLI version')
            [CompletionResult]::new('--home', '--home', [CompletionResultType]::ParameterName, 'Set the home directory')
            [CompletionResult]::new('--key-store', '--key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', '--cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--keyring', '--keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--known-notation', '--known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', '--time', [CompletionResultType]::ParameterName, 'Set the reference time as an ISO 8601 formatted timestamp')
            [CompletionResult]::new('--policy-as-of', '--policy-as-of', [CompletionResultType]::ParameterName, 'Select the cryptographic policy as of the specified time')
            [CompletionResult]::new('--trust-root', '--trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('--password-file', '--password-file', [CompletionResultType]::ParameterName, 'Seed the password cache with the specified password')
            [CompletionResult]::new('--overwrite', '--overwrite', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('-v', '-v', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('--verbose', '--verbose', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--batch', '--batch', [CompletionResultType]::ParameterName, 'Prevents any kind of prompting')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;config;inspect;policy' {
            [CompletionResult]::new('--cli-version', '--cli-version', [CompletionResultType]::ParameterName, 'Select a CLI version')
            [CompletionResult]::new('--home', '--home', [CompletionResultType]::ParameterName, 'Set the home directory')
            [CompletionResult]::new('--key-store', '--key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', '--cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--keyring', '--keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--known-notation', '--known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', '--time', [CompletionResultType]::ParameterName, 'Set the reference time as an ISO 8601 formatted timestamp')
            [CompletionResult]::new('--policy-as-of', '--policy-as-of', [CompletionResultType]::ParameterName, 'Select the cryptographic policy as of the specified time')
            [CompletionResult]::new('--trust-root', '--trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('--password-file', '--password-file', [CompletionResultType]::ParameterName, 'Seed the password cache with the specified password')
            [CompletionResult]::new('--overwrite', '--overwrite', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('-v', '-v', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('--verbose', '--verbose', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--batch', '--batch', [CompletionResultType]::ParameterName, 'Prevents any kind of prompting')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;config;template' {
            [CompletionResult]::new('--output', '--output', [CompletionResultType]::ParameterName, 'Write to FILE or stdout if omitted')
            [CompletionResult]::new('--cli-version', '--cli-version', [CompletionResultType]::ParameterName, 'Select a CLI version')
            [CompletionResult]::new('--home', '--home', [CompletionResultType]::ParameterName, 'Set the home directory')
            [CompletionResult]::new('--key-store', '--key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', '--cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--keyring', '--keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--known-notation', '--known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', '--time', [CompletionResultType]::ParameterName, 'Set the reference time as an ISO 8601 formatted timestamp')
            [CompletionResult]::new('--policy-as-of', '--policy-as-of', [CompletionResultType]::ParameterName, 'Select the cryptographic policy as of the specified time')
            [CompletionResult]::new('--trust-root', '--trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('--password-file', '--password-file', [CompletionResultType]::ParameterName, 'Seed the password cache with the specified password')
            [CompletionResult]::new('--overwrite', '--overwrite', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('-v', '-v', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('--verbose', '--verbose', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--batch', '--batch', [CompletionResultType]::ParameterName, 'Prevents any kind of prompting')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;version' {
            [CompletionResult]::new('--cli-version', '--cli-version', [CompletionResultType]::ParameterName, 'Select a CLI version')
            [CompletionResult]::new('--home', '--home', [CompletionResultType]::ParameterName, 'Set the home directory')
            [CompletionResult]::new('--key-store', '--key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', '--cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--keyring', '--keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--known-notation', '--known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', '--time', [CompletionResultType]::ParameterName, 'Set the reference time as an ISO 8601 formatted timestamp')
            [CompletionResult]::new('--policy-as-of', '--policy-as-of', [CompletionResultType]::ParameterName, 'Select the cryptographic policy as of the specified time')
            [CompletionResult]::new('--trust-root', '--trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('--password-file', '--password-file', [CompletionResultType]::ParameterName, 'Seed the password cache with the specified password')
            [CompletionResult]::new('--overwrite', '--overwrite', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('-v', '-v', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('--verbose', '--verbose', [CompletionResultType]::ParameterName, 'Be more verbose')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Be more quiet')
            [CompletionResult]::new('--batch', '--batch', [CompletionResultType]::ParameterName, 'Prevents any kind of prompting')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;help' {
            [CompletionResult]::new('encrypt', 'encrypt', [CompletionResultType]::ParameterValue, 'Encrypt a message')
            [CompletionResult]::new('decrypt', 'decrypt', [CompletionResultType]::ParameterValue, 'Decrypt a message')
            [CompletionResult]::new('sign', 'sign', [CompletionResultType]::ParameterValue, 'Sign messages or data files')
            [CompletionResult]::new('verify', 'verify', [CompletionResultType]::ParameterValue, 'Verify signed messages or detached signatures')
            [CompletionResult]::new('download', 'download', [CompletionResultType]::ParameterValue, 'Download and authenticate the data')
            [CompletionResult]::new('inspect', 'inspect', [CompletionResultType]::ParameterValue, 'Inspect data, like file(1)')
            [CompletionResult]::new('cert', 'cert', [CompletionResultType]::ParameterValue, 'Manage certificates')
            [CompletionResult]::new('key', 'key', [CompletionResultType]::ParameterValue, 'Manage keys')
            [CompletionResult]::new('pki', 'pki', [CompletionResultType]::ParameterValue, 'Authenticate certs using the Web of Trust')
            [CompletionResult]::new('network', 'network', [CompletionResultType]::ParameterValue, 'Retrieve and publish certificates over the network')
            [CompletionResult]::new('keyring', 'keyring', [CompletionResultType]::ParameterValue, 'Manage collections of keys or certs')
            [CompletionResult]::new('packet', 'packet', [CompletionResultType]::ParameterValue, 'Low-level packet manipulation')
            [CompletionResult]::new('config', 'config', [CompletionResultType]::ParameterValue, 'Query, inspect, and create the configuration file')
            [CompletionResult]::new('version', 'version', [CompletionResultType]::ParameterValue, 'Detailed version and output version information')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'sq;help;encrypt' {
            break
        }
        'sq;help;decrypt' {
            break
        }
        'sq;help;sign' {
            break
        }
        'sq;help;verify' {
            break
        }
        'sq;help;download' {
            break
        }
        'sq;help;inspect' {
            break
        }
        'sq;help;cert' {
            [CompletionResult]::new('import', 'import', [CompletionResultType]::ParameterValue, 'Import certificates into the local certificate store')
            [CompletionResult]::new('export', 'export', [CompletionResultType]::ParameterValue, 'Export certificates from the local certificate store')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List certificates and user IDs')
            [CompletionResult]::new('lint', 'lint', [CompletionResultType]::ParameterValue, 'Check certificates for issues')
            break
        }
        'sq;help;cert;import' {
            break
        }
        'sq;help;cert;export' {
            break
        }
        'sq;help;cert;list' {
            break
        }
        'sq;help;cert;lint' {
            break
        }
        'sq;help;key' {
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List keys managed by the key store')
            [CompletionResult]::new('generate', 'generate', [CompletionResultType]::ParameterValue, 'Generate a new key')
            [CompletionResult]::new('rotate', 'rotate', [CompletionResultType]::ParameterValue, 'Rotate a certificate')
            [CompletionResult]::new('import', 'import', [CompletionResultType]::ParameterValue, 'Import keys into the key store')
            [CompletionResult]::new('export', 'export', [CompletionResultType]::ParameterValue, 'Export keys from the key store')
            [CompletionResult]::new('delete', 'delete', [CompletionResultType]::ParameterValue, 'Delete a certificate''s secret key material')
            [CompletionResult]::new('password', 'password', [CompletionResultType]::ParameterValue, 'Change the password protecting secret key material')
            [CompletionResult]::new('expire', 'expire', [CompletionResultType]::ParameterValue, 'Change a certificate''s expiration time')
            [CompletionResult]::new('revoke', 'revoke', [CompletionResultType]::ParameterValue, 'Revoke a certificate')
            [CompletionResult]::new('userid', 'userid', [CompletionResultType]::ParameterValue, 'Manage User IDs')
            [CompletionResult]::new('subkey', 'subkey', [CompletionResultType]::ParameterValue, 'Manage subkeys')
            [CompletionResult]::new('approvals', 'approvals', [CompletionResultType]::ParameterValue, 'Manages certification approvals')
            break
        }
        'sq;help;key;list' {
            break
        }
        'sq;help;key;generate' {
            break
        }
        'sq;help;key;rotate' {
            break
        }
        'sq;help;key;import' {
            break
        }
        'sq;help;key;export' {
            break
        }
        'sq;help;key;delete' {
            break
        }
        'sq;help;key;password' {
            break
        }
        'sq;help;key;expire' {
            break
        }
        'sq;help;key;revoke' {
            break
        }
        'sq;help;key;userid' {
            [CompletionResult]::new('add', 'add', [CompletionResultType]::ParameterValue, 'Add a user ID')
            [CompletionResult]::new('revoke', 'revoke', [CompletionResultType]::ParameterValue, 'Revoke a user ID')
            break
        }
        'sq;help;key;userid;add' {
            break
        }
        'sq;help;key;userid;revoke' {
            break
        }
        'sq;help;key;subkey' {
            [CompletionResult]::new('add', 'add', [CompletionResultType]::ParameterValue, 'Add a new subkey to a certificate')
            [CompletionResult]::new('export', 'export', [CompletionResultType]::ParameterValue, 'Export secret key material from the secret key store')
            [CompletionResult]::new('delete', 'delete', [CompletionResultType]::ParameterValue, 'Delete a certificate''s secret key material')
            [CompletionResult]::new('password', 'password', [CompletionResultType]::ParameterValue, 'Change the password protecting secret key material')
            [CompletionResult]::new('expire', 'expire', [CompletionResultType]::ParameterValue, 'Change a subkey''s expiration time')
            [CompletionResult]::new('revoke', 'revoke', [CompletionResultType]::ParameterValue, 'Revoke a subkey')
            [CompletionResult]::new('bind', 'bind', [CompletionResultType]::ParameterValue, 'Bind keys from one certificate to another')
            break
        }
        'sq;help;key;subkey;add' {
            break
        }
        'sq;help;key;subkey;export' {
            break
        }
        'sq;help;key;subkey;delete' {
            break
        }
        'sq;help;key;subkey;password' {
            break
        }
        'sq;help;key;subkey;expire' {
            break
        }
        'sq;help;key;subkey;revoke' {
            break
        }
        'sq;help;key;subkey;bind' {
            break
        }
        'sq;help;key;approvals' {
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'Lists third-party certifications and their approval status')
            [CompletionResult]::new('update', 'update', [CompletionResultType]::ParameterValue, 'Approves of third-party certifications allowing for their distribution')
            break
        }
        'sq;help;key;approvals;list' {
            break
        }
        'sq;help;key;approvals;update' {
            break
        }
        'sq;help;pki' {
            [CompletionResult]::new('authenticate', 'authenticate', [CompletionResultType]::ParameterValue, 'Authenticate a binding')
            [CompletionResult]::new('lookup', 'lookup', [CompletionResultType]::ParameterValue, 'Lookup the certificates associated with a User ID')
            [CompletionResult]::new('identify', 'identify', [CompletionResultType]::ParameterValue, 'Identify a certificate')
            [CompletionResult]::new('vouch', 'vouch', [CompletionResultType]::ParameterValue, 'Manage certifications')
            [CompletionResult]::new('link', 'link', [CompletionResultType]::ParameterValue, 'Manage authenticated certificate and User ID links')
            [CompletionResult]::new('path', 'path', [CompletionResultType]::ParameterValue, 'Verify the specified path')
            break
        }
        'sq;help;pki;authenticate' {
            break
        }
        'sq;help;pki;lookup' {
            break
        }
        'sq;help;pki;identify' {
            break
        }
        'sq;help;pki;vouch' {
            [CompletionResult]::new('add', 'add', [CompletionResultType]::ParameterValue, 'Certify a User ID for a Certificate')
            [CompletionResult]::new('authorize', 'authorize', [CompletionResultType]::ParameterValue, 'Mark a certificate as a trusted introducer')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List certifications')
            [CompletionResult]::new('replay', 'replay', [CompletionResultType]::ParameterValue, 'Replays vouches')
            break
        }
        'sq;help;pki;vouch;add' {
            break
        }
        'sq;help;pki;vouch;authorize' {
            break
        }
        'sq;help;pki;vouch;list' {
            break
        }
        'sq;help;pki;vouch;replay' {
            break
        }
        'sq;help;pki;link' {
            [CompletionResult]::new('add', 'add', [CompletionResultType]::ParameterValue, 'Link a certificate and a user ID')
            [CompletionResult]::new('authorize', 'authorize', [CompletionResultType]::ParameterValue, 'Make a certificate a trusted introducer')
            [CompletionResult]::new('retract', 'retract', [CompletionResultType]::ParameterValue, 'Retract links')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List links')
            break
        }
        'sq;help;pki;link;add' {
            break
        }
        'sq;help;pki;link;authorize' {
            break
        }
        'sq;help;pki;link;retract' {
            break
        }
        'sq;help;pki;link;list' {
            break
        }
        'sq;help;pki;path' {
            break
        }
        'sq;help;network' {
            [CompletionResult]::new('search', 'search', [CompletionResultType]::ParameterValue, 'Retrieve certificates using all supported network services')
            [CompletionResult]::new('keyserver', 'keyserver', [CompletionResultType]::ParameterValue, 'Retrieve and publishes certificates via key servers')
            [CompletionResult]::new('wkd', 'wkd', [CompletionResultType]::ParameterValue, 'Retrieve and publishes certificates via Web Key Directories')
            [CompletionResult]::new('dane', 'dane', [CompletionResultType]::ParameterValue, 'Retrieve and publishes certificates via DANE')
            break
        }
        'sq;help;network;search' {
            break
        }
        'sq;help;network;keyserver' {
            [CompletionResult]::new('search', 'search', [CompletionResultType]::ParameterValue, 'Retrieve certificates from key servers')
            [CompletionResult]::new('publish', 'publish', [CompletionResultType]::ParameterValue, 'Publish certificates on key servers')
            break
        }
        'sq;help;network;keyserver;search' {
            break
        }
        'sq;help;network;keyserver;publish' {
            break
        }
        'sq;help;network;wkd' {
            [CompletionResult]::new('search', 'search', [CompletionResultType]::ParameterValue, 'Retrieve certificates from a Web Key Directory')
            [CompletionResult]::new('publish', 'publish', [CompletionResultType]::ParameterValue, 'Publish certificates in a Web Key Directory')
            break
        }
        'sq;help;network;wkd;search' {
            break
        }
        'sq;help;network;wkd;publish' {
            break
        }
        'sq;help;network;dane' {
            [CompletionResult]::new('search', 'search', [CompletionResultType]::ParameterValue, 'Retrieve certificates using DANE')
            [CompletionResult]::new('generate', 'generate', [CompletionResultType]::ParameterValue, 'Generate DANE records for the given domain and certs')
            break
        }
        'sq;help;network;dane;search' {
            break
        }
        'sq;help;network;dane;generate' {
            break
        }
        'sq;help;keyring' {
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List keys in a keyring')
            [CompletionResult]::new('split', 'split', [CompletionResultType]::ParameterValue, 'Split a keyring into individual keys')
            [CompletionResult]::new('merge', 'merge', [CompletionResultType]::ParameterValue, 'Merge keys or keyrings into a single keyring')
            [CompletionResult]::new('filter', 'filter', [CompletionResultType]::ParameterValue, 'Join keys into a keyring applying a filter')
            break
        }
        'sq;help;keyring;list' {
            break
        }
        'sq;help;keyring;split' {
            break
        }
        'sq;help;keyring;merge' {
            break
        }
        'sq;help;keyring;filter' {
            break
        }
        'sq;help;packet' {
            [CompletionResult]::new('armor', 'armor', [CompletionResultType]::ParameterValue, 'Convert binary to ASCII')
            [CompletionResult]::new('dearmor', 'dearmor', [CompletionResultType]::ParameterValue, 'Convert ASCII to binary')
            [CompletionResult]::new('dump', 'dump', [CompletionResultType]::ParameterValue, 'List packets')
            [CompletionResult]::new('decrypt', 'decrypt', [CompletionResultType]::ParameterValue, 'Unwrap an encryption container')
            [CompletionResult]::new('split', 'split', [CompletionResultType]::ParameterValue, 'Split a message into packets')
            [CompletionResult]::new('join', 'join', [CompletionResultType]::ParameterValue, 'Join packets split across files')
            break
        }
        'sq;help;packet;armor' {
            break
        }
        'sq;help;packet;dearmor' {
            break
        }
        'sq;help;packet;dump' {
            break
        }
        'sq;help;packet;decrypt' {
            break
        }
        'sq;help;packet;split' {
            break
        }
        'sq;help;packet;join' {
            break
        }
        'sq;help;config' {
            [CompletionResult]::new('get', 'get', [CompletionResultType]::ParameterValue, 'Get configuration options')
            [CompletionResult]::new('inspect', 'inspect', [CompletionResultType]::ParameterValue, 'Inspect effective configuration details')
            [CompletionResult]::new('template', 'template', [CompletionResultType]::ParameterValue, 'Write a template configuration file')
            break
        }
        'sq;help;config;get' {
            break
        }
        'sq;help;config;inspect' {
            [CompletionResult]::new('paths', 'paths', [CompletionResultType]::ParameterValue, 'Inspect relevant paths')
            [CompletionResult]::new('network', 'network', [CompletionResultType]::ParameterValue, 'Inspect the network configuration')
            [CompletionResult]::new('policy', 'policy', [CompletionResultType]::ParameterValue, 'Inspect the cryptographic policy')
            break
        }
        'sq;help;config;inspect;paths' {
            break
        }
        'sq;help;config;inspect;network' {
            break
        }
        'sq;help;config;inspect;policy' {
            break
        }
        'sq;help;config;template' {
            break
        }
        'sq;help;version' {
            break
        }
        'sq;help;help' {
            break
        }
    })

    $completions.Where{ $_.CompletionText -like "$wordToComplete*" } |
        Sort-Object -Property ListItemText
}
